@@ -13,6 +13,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgsannotationitemwidget_impl.h"
+#include "moc_qgsannotationitemwidget_impl.cpp"
 
 #include "qgssymbolselectordialog.h"
 #include "qgsstyle.h"
@@ -45,12 +46,11 @@ QgsAnnotationPolygonItemWidget::QgsAnnotationPolygonItemWidget( QWidget *parent
 
   mSelector = new QgsSymbolSelectorWidget( mSymbol.get(), QgsStyle::defaultStyle(), nullptr, nullptr );
   mSelector->setDockMode( dockMode() );
-  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [ = ]
-  {
+  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [=] {
     if ( !mBlockChangedSignal )
     {
       emit itemChanged();
-      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "polygon_annotation_item" ), qgis::down_cast< QgsFillSymbol * >( mSelector->symbol()->clone() ) );
+      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "polygon_annotation_item" ), qgis::down_cast<QgsFillSymbol *>( mSelector->symbol()->clone() ) );
     }
   } );
   connect( mSelector, &QgsPanelWidget::showPanel, this, &QgsPanelWidget::openPanel );
@@ -60,8 +60,7 @@ QgsAnnotationPolygonItemWidget::QgsAnnotationPolygonItemWidget( QWidget *parent
   layout->addWidget( mSelector );
   mSymbolSelectorFrame->setLayout( layout );
 
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -77,7 +76,7 @@ QgsAnnotationItem *QgsAnnotationPolygonItemWidget::createItem()
 
 void QgsAnnotationPolygonItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationPolygonItem *polygonItem = dynamic_cast< QgsAnnotationPolygonItem * >( item ) )
+  if ( QgsAnnotationPolygonItem *polygonItem = dynamic_cast<QgsAnnotationPolygonItem *>( item ) )
   {
     polygonItem->setSymbol( mSymbol->clone() );
     mPropertiesWidget->updateItem( polygonItem );
@@ -103,7 +102,7 @@ QgsAnnotationPolygonItemWidget::~QgsAnnotationPolygonItemWidget() = default;
 
 bool QgsAnnotationPolygonItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationPolygonItem *polygonItem = dynamic_cast< QgsAnnotationPolygonItem * >( item );
+  QgsAnnotationPolygonItem *polygonItem = dynamic_cast<QgsAnnotationPolygonItem *>( item );
   if ( !polygonItem )
     return false;
 
@@ -137,12 +136,11 @@ QgsAnnotationLineItemWidget::QgsAnnotationLineItemWidget( QWidget *parent )
 
   mSelector = new QgsSymbolSelectorWidget( mSymbol.get(), QgsStyle::defaultStyle(), nullptr, nullptr );
   mSelector->setDockMode( dockMode() );
-  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [ = ]
-  {
+  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [=] {
     if ( !mBlockChangedSignal )
     {
       emit itemChanged();
-      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "line_annotation_item" ), qgis::down_cast< QgsLineSymbol * >( mSelector->symbol()->clone() ) );
+      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "line_annotation_item" ), qgis::down_cast<QgsLineSymbol *>( mSelector->symbol()->clone() ) );
     }
   } );
   connect( mSelector, &QgsPanelWidget::showPanel, this, &QgsPanelWidget::openPanel );
@@ -152,8 +150,7 @@ QgsAnnotationLineItemWidget::QgsAnnotationLineItemWidget( QWidget *parent )
   layout->addWidget( mSelector );
   mSymbolSelectorFrame->setLayout( layout );
 
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -169,7 +166,7 @@ QgsAnnotationItem *QgsAnnotationLineItemWidget::createItem()
 
 void QgsAnnotationLineItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationLineItem *lineItem = dynamic_cast< QgsAnnotationLineItem * >( item ) )
+  if ( QgsAnnotationLineItem *lineItem = dynamic_cast<QgsAnnotationLineItem *>( item ) )
   {
     lineItem->setSymbol( mSymbol->clone() );
     mPropertiesWidget->updateItem( lineItem );
@@ -195,7 +192,7 @@ QgsAnnotationLineItemWidget::~QgsAnnotationLineItemWidget() = default;
 
 bool QgsAnnotationLineItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationLineItem *lineItem = dynamic_cast< QgsAnnotationLineItem * >( item );
+  QgsAnnotationLineItem *lineItem = dynamic_cast<QgsAnnotationLineItem *>( item );
   if ( !lineItem )
     return false;
 
@@ -229,12 +226,11 @@ QgsAnnotationMarkerItemWidget::QgsAnnotationMarkerItemWidget( QWidget *parent )
 
   mSelector = new QgsSymbolSelectorWidget( mSymbol.get(), QgsStyle::defaultStyle(), nullptr, nullptr );
   mSelector->setDockMode( dockMode() );
-  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [ = ]
-  {
+  connect( mSelector, &QgsSymbolSelectorWidget::symbolModified, this, [=] {
     if ( !mBlockChangedSignal )
     {
       emit itemChanged();
-      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "marker_annotation_item" ), qgis::down_cast< QgsMarkerSymbol * >( mSelector->symbol()->clone() ) );
+      QgsApplication::recentStyleHandler()->pushRecentSymbol( QStringLiteral( "marker_annotation_item" ), qgis::down_cast<QgsMarkerSymbol *>( mSelector->symbol()->clone() ) );
     }
   } );
   connect( mSelector, &QgsPanelWidget::showPanel, this, &QgsPanelWidget::openPanel );
@@ -244,8 +240,7 @@ QgsAnnotationMarkerItemWidget::QgsAnnotationMarkerItemWidget( QWidget *parent )
   layout->addWidget( mSelector );
   mSymbolSelectorFrame->setLayout( layout );
 
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -261,7 +256,7 @@ QgsAnnotationItem *QgsAnnotationMarkerItemWidget::createItem()
 
 void QgsAnnotationMarkerItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationMarkerItem *markerItem = dynamic_cast< QgsAnnotationMarkerItem * >( item ) )
+  if ( QgsAnnotationMarkerItem *markerItem = dynamic_cast<QgsAnnotationMarkerItem *>( item ) )
   {
     markerItem->setSymbol( mSymbol->clone() );
     mPropertiesWidget->updateItem( markerItem );
@@ -287,7 +282,7 @@ QgsAnnotationMarkerItemWidget::~QgsAnnotationMarkerItemWidget() = default;
 
 bool QgsAnnotationMarkerItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationMarkerItem *markerItem = dynamic_cast< QgsAnnotationMarkerItem * >( item );
+  QgsAnnotationMarkerItem *markerItem = dynamic_cast<QgsAnnotationMarkerItem *>( item );
   if ( !markerItem )
     return false;
 
@@ -310,7 +305,6 @@ bool QgsAnnotationMarkerItemWidget::setNewItem( QgsAnnotationItem *item )
 }
 
 
-
 //
 // QgsAnnotationPointTextItemWidget
 //
@@ -337,8 +331,7 @@ QgsAnnotationPointTextItemWidget::QgsAnnotationPointTextItemWidget( QWidget *par
   mAlignmentComboBox->setAvailableAlignments( Qt::AlignLeft | Qt::AlignHCenter | Qt::AlignRight );
 
   mTextFormatWidget->setDockMode( dockMode() );
-  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [ = ]
-  {
+  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [=] {
     mTextEdit->setMode(
       mTextFormatWidget->format().allowHtmlFormatting() ? QgsRichTextEditor::Mode::QgsTextRenderer : QgsRichTextEditor::Mode::PlainText
     );
@@ -346,32 +339,27 @@ QgsAnnotationPointTextItemWidget::QgsAnnotationPointTextItemWidget( QWidget *par
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
-  connect( mTextEdit, &QgsRichTextEditor::textChanged, this, [ = ]
-  {
+  connect( mTextEdit, &QgsRichTextEditor::textChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
   connect( mInsertExpressionButton, &QPushButton::clicked, this, &QgsAnnotationPointTextItemWidget::mInsertExpressionButton_clicked );
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
 
-  connect( mSpinTextAngle, qOverload< double >( &QgsDoubleSpinBox::valueChanged ), this, [ = ]
-  {
+  connect( mSpinTextAngle, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
 
-  connect( mRotationModeCombo, qOverload< int >( &QComboBox::currentIndexChanged ), this, [ = ]
-  {
+  connect( mRotationModeCombo, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
 
-  connect( mAlignmentComboBox, &QgsAlignmentComboBox::changed, this, [ = ]
-  {
+  connect( mAlignmentComboBox, &QgsAlignmentComboBox::changed, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -386,13 +374,13 @@ QgsAnnotationItem *QgsAnnotationPointTextItemWidget::createItem()
 
 void QgsAnnotationPointTextItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationPointTextItem *pointTextItem = dynamic_cast< QgsAnnotationPointTextItem * >( item ) )
+  if ( QgsAnnotationPointTextItem *pointTextItem = dynamic_cast<QgsAnnotationPointTextItem *>( item ) )
   {
     mBlockChangedSignal = true;
     pointTextItem->setFormat( mTextFormatWidget->format() );
     pointTextItem->setText( mTextFormatWidget->format().allowHtmlFormatting() ? mTextEdit->toHtml() : mTextEdit->toPlainText() );
     pointTextItem->setAngle( mSpinTextAngle->value() );
-    pointTextItem->setRotationMode( mRotationModeCombo->currentData().value< Qgis::SymbolRotationMode >() );
+    pointTextItem->setRotationMode( mRotationModeCombo->currentData().value<Qgis::SymbolRotationMode>() );
     pointTextItem->setAlignment( mAlignmentComboBox->currentAlignment() );
     mBlockChangedSignal = false;
     mPropertiesWidget->updateItem( pointTextItem );
@@ -424,7 +412,7 @@ QgsAnnotationPointTextItemWidget::~QgsAnnotationPointTextItemWidget() = default;
 
 bool QgsAnnotationPointTextItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationPointTextItem *textItem = dynamic_cast< QgsAnnotationPointTextItem * >( item );
+  QgsAnnotationPointTextItem *textItem = dynamic_cast<QgsAnnotationPointTextItem *>( item );
   if ( !textItem )
     return false;
 
@@ -486,8 +474,7 @@ QgsAnnotationLineTextItemWidget::QgsAnnotationLineTextItemWidget( QWidget *paren
   mTextEdit->setMaximumHeight( mTextEdit->fontMetrics().height() * 10 );
 
   mTextFormatWidget->setDockMode( dockMode() );
-  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [ = ]
-  {
+  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [=] {
     mTextEdit->setMode(
       mTextFormatWidget->format().allowHtmlFormatting() ? QgsRichTextEditor::Mode::QgsTextRenderer : QgsRichTextEditor::Mode::PlainText
     );
@@ -495,29 +482,24 @@ QgsAnnotationLineTextItemWidget::QgsAnnotationLineTextItemWidget( QWidget *paren
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
-  connect( mTextEdit, &QgsRichTextEditor::textChanged, this, [ = ]
-  {
+  connect( mTextEdit, &QgsRichTextEditor::textChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
   connect( mInsertExpressionButton, &QPushButton::clicked, this, &QgsAnnotationLineTextItemWidget::mInsertExpressionButton_clicked );
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
 
-  mOffsetUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::MetersInMapUnits << Qgis::RenderUnit::MapUnits << Qgis::RenderUnit::Pixels
-                               << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches );
+  mOffsetUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::MetersInMapUnits << Qgis::RenderUnit::MapUnits << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches );
   mSpinOffset->setClearValue( 0.0 );
-  connect( mSpinOffset, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, [ = ]
-  {
+  connect( mSpinOffset, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
 
-  connect( mOffsetUnitWidget, &QgsUnitSelectionWidget::changed, this, [ = ]
-  {
+  connect( mOffsetUnitWidget, &QgsUnitSelectionWidget::changed, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -534,7 +516,7 @@ QgsAnnotationItem *QgsAnnotationLineTextItemWidget::createItem()
 
 void QgsAnnotationLineTextItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationLineTextItem *lineTextItem = dynamic_cast< QgsAnnotationLineTextItem * >( item ) )
+  if ( QgsAnnotationLineTextItem *lineTextItem = dynamic_cast<QgsAnnotationLineTextItem *>( item ) )
   {
     mBlockChangedSignal = true;
     lineTextItem->setFormat( mTextFormatWidget->format() );
@@ -572,7 +554,7 @@ void QgsAnnotationLineTextItemWidget::focusDefaultWidget()
 
 bool QgsAnnotationLineTextItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationLineTextItem *textItem = dynamic_cast< QgsAnnotationLineTextItem * >( item );
+  QgsAnnotationLineTextItem *textItem = dynamic_cast<QgsAnnotationLineTextItem *>( item );
   if ( !textItem )
     return false;
 
@@ -617,7 +599,6 @@ void QgsAnnotationLineTextItemWidget::mInsertExpressionButton_clicked()
 }
 
 
-
 //
 // QgsAnnotationRectangleTextItemWidget
 //
@@ -631,8 +612,7 @@ QgsAnnotationRectangleTextItemWidget::QgsAnnotationRectangleTextItemWidget( QWid
   mSizeModeCombo->addItem( tr( "Fixed Size" ), QVariant::fromValue( Qgis::AnnotationPlacementMode::FixedSize ) );
   mSizeModeCombo->addItem( tr( "Relative to Map" ), QVariant::fromValue( Qgis::AnnotationPlacementMode::RelativeToMapFrame ) );
 
-  mSizeUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Millimeters
-                             << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches << Qgis::RenderUnit::Percentage );
+  mSizeUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches << Qgis::RenderUnit::Percentage );
 
 
   mBackgroundSymbolButton->setSymbolType( Qgis::SymbolType::Fill );
@@ -646,8 +626,7 @@ QgsAnnotationRectangleTextItemWidget::QgsAnnotationRectangleTextItemWidget( QWid
   mSpinTopMargin->setClearValue( 0 );
   mSpinRightMargin->setClearValue( 0 );
   mSpinLeftMargin->setClearValue( 0 );
-  mMarginUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::MetersInMapUnits << Qgis::RenderUnit::MapUnits << Qgis::RenderUnit::Pixels
-                               << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches );
+  mMarginUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::MetersInMapUnits << Qgis::RenderUnit::MapUnits << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches );
 
   mTextFormatWidget = new QgsTextFormatWidget();
   QVBoxLayout *vLayout = new QVBoxLayout();
@@ -662,8 +641,7 @@ QgsAnnotationRectangleTextItemWidget::QgsAnnotationRectangleTextItemWidget( QWid
   mVerticalAlignmentComboBox->setAvailableAlignments( Qt::AlignTop | Qt::AlignVCenter | Qt::AlignBottom );
 
   mTextFormatWidget->setDockMode( dockMode() );
-  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [this]
-  {
+  connect( mTextFormatWidget, &QgsTextFormatWidget::widgetChanged, this, [this] {
     mTextEdit->setMode(
       mTextFormatWidget->format().allowHtmlFormatting() ? QgsRichTextEditor::Mode::QgsTextRenderer : QgsRichTextEditor::Mode::PlainText
     );
@@ -679,16 +657,16 @@ QgsAnnotationRectangleTextItemWidget::QgsAnnotationRectangleTextItemWidget( QWid
   connect( mBackgroundCheckbox, &QGroupBox::toggled, this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
   connect( mBackgroundSymbolButton, &QgsSymbolButton::changed, this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
   connect( mFrameSymbolButton, &QgsSymbolButton::changed, this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
-  connect( mSpinTopMargin, qOverload< double >( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
-  connect( mSpinRightMargin, qOverload< double >( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
-  connect( mSpinLeftMargin, qOverload< double >( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
-  connect( mSpinBottomMargin, qOverload< double >( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
+  connect( mSpinTopMargin, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
+  connect( mSpinRightMargin, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
+  connect( mSpinLeftMargin, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
+  connect( mSpinBottomMargin, qOverload<double>( &QgsDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
   connect( mMarginUnitWidget, &QgsUnitSelectionWidget::changed, this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
 
   connect( mSizeUnitWidget, &QgsUnitSelectionWidget::changed, this, &QgsAnnotationRectangleTextItemWidget::onWidgetChanged );
 
-  connect( mWidthSpinBox, qOverload< double >( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::setWidth );
-  connect( mHeightSpinBox, qOverload< double >( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::setHeight );
+  connect( mWidthSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::setWidth );
+  connect( mHeightSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationRectangleTextItemWidget::setHeight );
 
   connect( mSizeModeCombo, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsAnnotationRectangleTextItemWidget::sizeModeChanged );
   mWidgetFixedSize->hide();
@@ -704,27 +682,24 @@ QgsAnnotationItem *QgsAnnotationRectangleTextItemWidget::createItem()
 
 void QgsAnnotationRectangleTextItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationRectangleTextItem *rectTextItem = dynamic_cast< QgsAnnotationRectangleTextItem * >( item ) )
+  if ( QgsAnnotationRectangleTextItem *rectTextItem = dynamic_cast<QgsAnnotationRectangleTextItem *>( item ) )
   {
     mBlockChangedSignal = true;
     rectTextItem->setFormat( mTextFormatWidget->format() );
     rectTextItem->setText( mTextFormatWidget->format().allowHtmlFormatting() ? mTextEdit->toHtml() : mTextEdit->toPlainText() );
     rectTextItem->setAlignment( mAlignmentComboBox->currentAlignment() | mVerticalAlignmentComboBox->currentAlignment() );
 
-    rectTextItem->setPlacementMode( mSizeModeCombo->currentData().value< Qgis::AnnotationPlacementMode >() );
+    rectTextItem->setPlacementMode( mSizeModeCombo->currentData().value<Qgis::AnnotationPlacementMode>() );
 
     rectTextItem->setFixedSize( QSizeF( mWidthSpinBox->value(), mHeightSpinBox->value() ) );
     rectTextItem->setFixedSizeUnit( mSizeUnitWidget->unit() );
 
     rectTextItem->setBackgroundEnabled( mBackgroundCheckbox->isChecked() );
     rectTextItem->setFrameEnabled( mFrameCheckbox->isChecked() );
-    rectTextItem->setBackgroundSymbol( mBackgroundSymbolButton->clonedSymbol< QgsFillSymbol >() );
-    rectTextItem->setFrameSymbol( mFrameSymbolButton->clonedSymbol< QgsFillSymbol >() );
+    rectTextItem->setBackgroundSymbol( mBackgroundSymbolButton->clonedSymbol<QgsFillSymbol>() );
+    rectTextItem->setFrameSymbol( mFrameSymbolButton->clonedSymbol<QgsFillSymbol>() );
 
-    rectTextItem->setMargins( QgsMargins( mSpinLeftMargin->value(),
-                                          mSpinTopMargin->value(),
-                                          mSpinRightMargin->value(),
-                                          mSpinBottomMargin->value() ) );
+    rectTextItem->setMargins( QgsMargins( mSpinLeftMargin->value(), mSpinTopMargin->value(), mSpinRightMargin->value(), mSpinBottomMargin->value() ) );
     rectTextItem->setMarginsUnit( mMarginUnitWidget->unit() );
 
     if ( mUpdateItemPosition )
@@ -778,7 +753,7 @@ QgsAnnotationRectangleTextItemWidget::~QgsAnnotationRectangleTextItemWidget() =
 
 bool QgsAnnotationRectangleTextItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationRectangleTextItem *textItem = dynamic_cast< QgsAnnotationRectangleTextItem * >( item );
+  QgsAnnotationRectangleTextItem *textItem = dynamic_cast<QgsAnnotationRectangleTextItem *>( item );
   if ( !textItem )
     return false;
 
@@ -823,7 +798,7 @@ void QgsAnnotationRectangleTextItemWidget::onWidgetChanged()
 
 void QgsAnnotationRectangleTextItemWidget::sizeModeChanged()
 {
-  const Qgis::AnnotationPlacementMode mode = mSizeModeCombo->currentData().value< Qgis::AnnotationPlacementMode >();
+  const Qgis::AnnotationPlacementMode mode = mSizeModeCombo->currentData().value<Qgis::AnnotationPlacementMode>();
   switch ( mode )
   {
     case Qgis::AnnotationPlacementMode::SpatialBounds:
@@ -900,8 +875,7 @@ QgsAnnotationPictureItemWidget::QgsAnnotationPictureItemWidget( QWidget *parent
   mSizeModeCombo->addItem( tr( "Fixed Size" ), QVariant::fromValue( Qgis::AnnotationPlacementMode::FixedSize ) );
   mSizeModeCombo->addItem( tr( "Relative to Map" ), QVariant::fromValue( Qgis::AnnotationPlacementMode::RelativeToMapFrame ) );
 
-  mSizeUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Millimeters
-                             << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches << Qgis::RenderUnit::Percentage );
+  mSizeUnitWidget->setUnits( QgsUnitTypes::RenderUnitList() << Qgis::RenderUnit::Pixels << Qgis::RenderUnit::Millimeters << Qgis::RenderUnit::Points << Qgis::RenderUnit::Inches << Qgis::RenderUnit::Percentage );
 
   mBackgroundSymbolButton->setSymbolType( Qgis::SymbolType::Fill );
   mBackgroundSymbolButton->setDialogTitle( tr( "Background" ) );
@@ -910,8 +884,7 @@ QgsAnnotationPictureItemWidget::QgsAnnotationPictureItemWidget( QWidget *parent
   mFrameSymbolButton->setDialogTitle( tr( "Frame" ) );
   mFrameSymbolButton->registerExpressionContextGenerator( this );
 
-  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [ = ]
-  {
+  connect( mPropertiesWidget, &QgsAnnotationItemCommonPropertiesWidget::itemChanged, this, [=] {
     if ( !mBlockChangedSignal )
       emit itemChanged();
   } );
@@ -920,8 +893,7 @@ QgsAnnotationPictureItemWidget::QgsAnnotationPictureItemWidget( QWidget *parent
 
   connect( mRadioSVG, &QRadioButton::toggled, this, &QgsAnnotationPictureItemWidget::modeChanged );
   connect( mRadioRaster, &QRadioButton::toggled, this, &QgsAnnotationPictureItemWidget::modeChanged );
-  connect( mSourceLineEdit, &QgsPictureSourceLineEditBase::sourceChanged, this, [ = ]( const QString & source )
-  {
+  connect( mSourceLineEdit, &QgsPictureSourceLineEditBase::sourceChanged, this, [=]( const QString &source ) {
     if ( !mRadioSVG->isChecked() && QFileInfo( source ).suffix().compare( QLatin1String( "svg" ), Qt::CaseInsensitive ) == 0 )
     {
       mRadioSVG->setChecked( true );
@@ -937,8 +909,8 @@ QgsAnnotationPictureItemWidget::QgsAnnotationPictureItemWidget( QWidget *parent
   connect( mFrameSymbolButton, &QgsSymbolButton::changed, this, &QgsAnnotationPictureItemWidget::onWidgetChanged );
   connect( mSizeUnitWidget, &QgsUnitSelectionWidget::changed, this, &QgsAnnotationPictureItemWidget::onWidgetChanged );
 
-  connect( mWidthSpinBox, qOverload< double >( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationPictureItemWidget::setWidth );
-  connect( mHeightSpinBox, qOverload< double >( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationPictureItemWidget::setHeight );
+  connect( mWidthSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationPictureItemWidget::setWidth );
+  connect( mHeightSpinBox, qOverload<double>( &QDoubleSpinBox::valueChanged ), this, &QgsAnnotationPictureItemWidget::setHeight );
   connect( mLockAspectRatio, &QgsRatioLockButton::lockChanged, this, &QgsAnnotationPictureItemWidget::setLockAspectRatio );
 }
 
@@ -953,14 +925,14 @@ QgsAnnotationItem *QgsAnnotationPictureItemWidget::createItem()
 
 void QgsAnnotationPictureItemWidget::updateItem( QgsAnnotationItem *item )
 {
-  if ( QgsAnnotationPictureItem *pictureItem = dynamic_cast< QgsAnnotationPictureItem * >( item ) )
+  if ( QgsAnnotationPictureItem *pictureItem = dynamic_cast<QgsAnnotationPictureItem *>( item ) )
   {
     const bool svg = mRadioSVG->isChecked();
     const Qgis::PictureFormat newFormat = svg ? Qgis::PictureFormat::SVG : Qgis::PictureFormat::Raster;
     const QString path = mSourceLineEdit->source();
     pictureItem->setPath( newFormat, path );
 
-    pictureItem->setPlacementMode( mSizeModeCombo->currentData().value< Qgis::AnnotationPlacementMode >() );
+    pictureItem->setPlacementMode( mSizeModeCombo->currentData().value<Qgis::AnnotationPlacementMode>() );
     switch ( pictureItem->placementMode() )
     {
       case Qgis::AnnotationPlacementMode::SpatialBounds:
@@ -977,8 +949,8 @@ void QgsAnnotationPictureItemWidget::updateItem( QgsAnnotationItem *item )
 
     pictureItem->setBackgroundEnabled( mBackgroundCheckbox->isChecked() );
     pictureItem->setFrameEnabled( mFrameCheckbox->isChecked() );
-    pictureItem->setBackgroundSymbol( mBackgroundSymbolButton->clonedSymbol< QgsFillSymbol >() );
-    pictureItem->setFrameSymbol( mFrameSymbolButton->clonedSymbol< QgsFillSymbol >() );
+    pictureItem->setBackgroundSymbol( mBackgroundSymbolButton->clonedSymbol<QgsFillSymbol>() );
+    pictureItem->setFrameSymbol( mFrameSymbolButton->clonedSymbol<QgsFillSymbol>() );
 
     if ( mUpdateItemPosition )
     {
@@ -1022,7 +994,7 @@ void QgsAnnotationPictureItemWidget::focusDefaultWidget()
 
 bool QgsAnnotationPictureItemWidget::setNewItem( QgsAnnotationItem *item )
 {
-  QgsAnnotationPictureItem *pictureItem = dynamic_cast< QgsAnnotationPictureItem * >( item );
+  QgsAnnotationPictureItem *pictureItem = dynamic_cast<QgsAnnotationPictureItem *>( item );
   if ( !pictureItem )
     return false;
 
@@ -1088,7 +1060,7 @@ void QgsAnnotationPictureItemWidget::modeChanged( bool checked )
 
 void QgsAnnotationPictureItemWidget::sizeModeChanged()
 {
-  const Qgis::AnnotationPlacementMode mode = mSizeModeCombo->currentData().value< Qgis::AnnotationPlacementMode >();
+  const Qgis::AnnotationPlacementMode mode = mSizeModeCombo->currentData().value<Qgis::AnnotationPlacementMode>();
   switch ( mode )
   {
     case Qgis::AnnotationPlacementMode::SpatialBounds:
@@ -1178,4 +1150,3 @@ double QgsAnnotationPictureItemWidget::pictureAspectRatio() const
 }
 
 ///@endcond PRIVATE
-
