@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsprocessingmaplayercombobox.h"
+#include "moc_qgsprocessingmaplayercombobox.cpp"
 #include "qgsmaplayercombobox.h"
 #include "qgsmimedatautils.h"
 #include "qgsprocessingparameters.h"
@@ -61,7 +62,7 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
     mIterateButton->setAutoRaise( true );
 
     // button width is 1.25 * icon size, height 1.1 * icon size. But we round to ensure even pixel sizes for equal margins
-    mIterateButton->setFixedSize( 2 * static_cast< int >( 1.25 * iconSize / 2.0 ), 2 * static_cast< int >( iconSize * 1.1 / 2.0 ) );
+    mIterateButton->setFixedSize( 2 * static_cast<int>( 1.25 * iconSize / 2.0 ), 2 * static_cast<int>( iconSize * 1.1 / 2.0 ) );
     mIterateButton->setIconSize( QSize( iconSize, iconSize ) );
 
     layout->addWidget( mIterateButton );
@@ -75,7 +76,7 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
     mSettingsButton->setToolTip( tr( "Advanced options" ) );
 
     // button width is 1.25 * icon size, height 1.1 * icon size. But we round to ensure even pixel sizes for equal margins
-    mSettingsButton->setFixedSize( 2 * static_cast< int >( 1.25 * iconSize / 2.0 ), 2 * static_cast< int >( iconSize * 1.1 / 2.0 ) );
+    mSettingsButton->setFixedSize( 2 * static_cast<int>( 1.25 * iconSize / 2.0 ), 2 * static_cast<int>( iconSize * 1.1 / 2.0 ) );
     mSettingsButton->setIconSize( QSize( iconSize, iconSize ) );
     mSettingsButton->setAutoRaise( true );
 
@@ -127,17 +128,17 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
   {
     QList<int> dataTypes;
     if ( mParameter->type() == QgsProcessingParameterFeatureSource::typeName() )
-      dataTypes = static_cast< QgsProcessingParameterFeatureSource *>( mParameter.get() )->dataTypes();
+      dataTypes = static_cast<QgsProcessingParameterFeatureSource *>( mParameter.get() )->dataTypes();
     else if ( mParameter->type() == QgsProcessingParameterVectorLayer::typeName() )
-      dataTypes = static_cast< QgsProcessingParameterVectorLayer *>( mParameter.get() )->dataTypes();
+      dataTypes = static_cast<QgsProcessingParameterVectorLayer *>( mParameter.get() )->dataTypes();
 
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.isEmpty() )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.isEmpty() )
       filters = Qgis::LayerFilter::HasGeometry;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPoint ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPoint ) ) )
       filters |= Qgis::LayerFilter::PointLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) ) )
       filters |= Qgis::LayerFilter::LineLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon ) ) )
       filters |= Qgis::LayerFilter::PolygonLayer;
     if ( !filters )
       filters = Qgis::LayerFilter::VectorLayer;
@@ -158,24 +159,24 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
   else if ( mParameter->type() == QgsProcessingParameterMapLayer::typeName() )
   {
     QList<int> dataTypes;
-    dataTypes = static_cast< QgsProcessingParameterMapLayer *>( mParameter.get() )->dataTypes();
+    dataTypes = static_cast<QgsProcessingParameterMapLayer *>( mParameter.get() )->dataTypes();
 
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) )
       filters |= Qgis::LayerFilter::HasGeometry;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPoint ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPoint ) ) )
       filters |= Qgis::LayerFilter::PointLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) ) )
       filters |= Qgis::LayerFilter::LineLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon ) ) )
       filters |= Qgis::LayerFilter::PolygonLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Raster ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Raster ) ) )
     {
       mayBeRaster = true;
       filters |= Qgis::LayerFilter::RasterLayer;
     }
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Mesh ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Mesh ) ) )
       filters |= Qgis::LayerFilter::MeshLayer;
-    if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::PointCloud ) ) )
+    if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::PointCloud ) ) )
       filters |= Qgis::LayerFilter::PointCloudLayer;
     if ( !filters )
       filters = Qgis::LayerFilter::All;
@@ -190,8 +191,7 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
 
   // Check compatibility with virtualraster data provider
   // see https://github.com/qgis/QGIS/issues/55890
-  if ( mayBeRaster &&
-       ( ! mParameter->provider() || ! mParameter->provider()->flags().testFlag( Qgis::ProcessingProviderFlag::CompatibleWithVirtualRaster ) ) )
+  if ( mayBeRaster && ( !mParameter->provider() || !mParameter->provider()->flags().testFlag( Qgis::ProcessingProviderFlag::CompatibleWithVirtualRaster ) ) )
   {
     mCombo->setExcludedProviders( mCombo->excludedProviders() << QStringLiteral( "virtualraster" ) );
   }
@@ -204,11 +204,10 @@ QgsProcessingMapLayerComboBox::QgsProcessingMapLayerComboBox( const QgsProcessin
 
   connect( mCombo, &QgsMapLayerComboBox::layerChanged, this, &QgsProcessingMapLayerComboBox::onLayerChanged );
   if ( mUseSelectionCheckBox )
-    connect( mUseSelectionCheckBox, &QCheckBox::toggled, this, [ = ]
-  {
-    if ( !mBlockChangedSignal )
-      emit valueChanged();
-  } );
+    connect( mUseSelectionCheckBox, &QCheckBox::toggled, this, [=] {
+      if ( !mBlockChangedSignal )
+        emit valueChanged();
+    } );
 
   setLayout( vl );
 
@@ -237,7 +236,7 @@ QString QgsProcessingMapLayerComboBox::currentText()
 
 void QgsProcessingMapLayerComboBox::setValue( const QVariant &value, QgsProcessingContext &context )
 {
-  if ( !value.isValid()  && mParameter->flags() & Qgis::ProcessingParameterFlag::Optional )
+  if ( !value.isValid() && mParameter->flags() & Qgis::ProcessingParameterFlag::Optional )
   {
     setLayer( nullptr );
     return;
@@ -268,17 +267,17 @@ void QgsProcessingMapLayerComboBox::setValue( const QVariant &value, QgsProcessi
 
   if ( val.userType() == qMetaTypeId<QgsProperty>() )
   {
-    if ( val.value< QgsProperty >().propertyType() == Qgis::PropertyType::Static )
+    if ( val.value<QgsProperty>().propertyType() == Qgis::PropertyType::Static )
     {
-      val = val.value< QgsProperty >().staticValue();
+      val = val.value<QgsProperty>().staticValue();
     }
     else
     {
-      val = val.value< QgsProperty >().valueAsString( context.expressionContext(), mParameter->defaultValueForGui().toString() );
+      val = val.value<QgsProperty>().valueAsString( context.expressionContext(), mParameter->defaultValueForGui().toString() );
     }
   }
 
-  QgsMapLayer *layer = qobject_cast< QgsMapLayer * >( val.value< QObject * >() );
+  QgsMapLayer *layer = qobject_cast<QgsMapLayer *>( val.value<QObject *>() );
   if ( !layer && val.userType() == QMetaType::Type::QString )
   {
     layer = QgsProcessingUtils::mapLayerFromString( val.toString(), context, false );
@@ -289,11 +288,11 @@ void QgsProcessingMapLayerComboBox::setValue( const QVariant &value, QgsProcessi
     mBlockChangedSignal++;
     QgsMapLayer *prevLayer = currentLayer();
     setLayer( layer );
-    found = static_cast< bool >( currentLayer() );
+    found = static_cast<bool>( currentLayer() );
     bool changed = found && ( currentLayer() != prevLayer );
     if ( found && mUseSelectionCheckBox )
     {
-      const bool hasSelection = qobject_cast< QgsVectorLayer * >( layer ) && qobject_cast< QgsVectorLayer * >( layer )->selectedFeatureCount() > 0;
+      const bool hasSelection = qobject_cast<QgsVectorLayer *>( layer ) && qobject_cast<QgsVectorLayer *>( layer )->selectedFeatureCount() > 0;
       changed = changed | ( ( hasSelection && selectedOnly ) != mUseSelectionCheckBox->isChecked() );
       if ( hasSelection )
       {
@@ -363,10 +362,7 @@ QVariant QgsProcessingMapLayerComboBox::value() const
   if ( QgsMapLayer *layer = mCombo->currentLayer() )
   {
     if ( selectedOnly || iterate || mFeatureLimit != -1 || mIsOverridingDefaultGeometryCheck || !mFilterExpression.isEmpty() )
-      return QgsProcessingFeatureSourceDefinition( layer->id(), selectedOnly, mFeatureLimit,
-             ( iterate ? Qgis::ProcessingFeatureSourceDefinitionFlag::CreateIndividualOutputPerInputFeature : Qgis::ProcessingFeatureSourceDefinitionFlags() )
-             | ( mIsOverridingDefaultGeometryCheck ? Qgis::ProcessingFeatureSourceDefinitionFlag::OverrideDefaultGeometryCheck : Qgis::ProcessingFeatureSourceDefinitionFlags() ),
-             mGeometryCheck, mFilterExpression );
+      return QgsProcessingFeatureSourceDefinition( layer->id(), selectedOnly, mFeatureLimit, ( iterate ? Qgis::ProcessingFeatureSourceDefinitionFlag::CreateIndividualOutputPerInputFeature : Qgis::ProcessingFeatureSourceDefinitionFlags() ) | ( mIsOverridingDefaultGeometryCheck ? Qgis::ProcessingFeatureSourceDefinitionFlag::OverrideDefaultGeometryCheck : Qgis::ProcessingFeatureSourceDefinitionFlags() ), mGeometryCheck, mFilterExpression );
     else
       return layer->id();
   }
@@ -375,10 +371,7 @@ QVariant QgsProcessingMapLayerComboBox::value() const
     if ( !mCombo->currentText().isEmpty() )
     {
       if ( selectedOnly || iterate || mFeatureLimit != -1 || mIsOverridingDefaultGeometryCheck || !mFilterExpression.isEmpty() )
-        return QgsProcessingFeatureSourceDefinition( mCombo->currentText(), selectedOnly, mFeatureLimit,
-               ( iterate ? Qgis::ProcessingFeatureSourceDefinitionFlag::CreateIndividualOutputPerInputFeature : Qgis::ProcessingFeatureSourceDefinitionFlags() )
-               | ( mIsOverridingDefaultGeometryCheck ? Qgis::ProcessingFeatureSourceDefinitionFlag::OverrideDefaultGeometryCheck : Qgis::ProcessingFeatureSourceDefinitionFlags() ),
-               mGeometryCheck, mFilterExpression );
+        return QgsProcessingFeatureSourceDefinition( mCombo->currentText(), selectedOnly, mFeatureLimit, ( iterate ? Qgis::ProcessingFeatureSourceDefinitionFlag::CreateIndividualOutputPerInputFeature : Qgis::ProcessingFeatureSourceDefinitionFlags() ) | ( mIsOverridingDefaultGeometryCheck ? Qgis::ProcessingFeatureSourceDefinitionFlag::OverrideDefaultGeometryCheck : Qgis::ProcessingFeatureSourceDefinitionFlags() ), mGeometryCheck, mFilterExpression );
       else
         return mCombo->currentText();
     }
@@ -433,9 +426,9 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
            || mParameter->type() == QgsProcessingParameterVectorLayer::typeName() )
          && u.layerType == QLatin1String( "vector" ) )
     {
-      QList< int > dataTypes =  mParameter->type() == QgsProcessingParameterFeatureSource::typeName() ? static_cast< QgsProcessingParameterFeatureSource * >( mParameter.get() )->dataTypes()
-                                : ( mParameter->type() == QgsProcessingParameterVectorLayer::typeName() ? static_cast<QgsProcessingParameterVectorLayer *>( mParameter.get() )->dataTypes()
-                                    : QList< int >() );
+      QList<int> dataTypes = mParameter->type() == QgsProcessingParameterFeatureSource::typeName() ? static_cast<QgsProcessingParameterFeatureSource *>( mParameter.get() )->dataTypes()
+                                                                                                   : ( mParameter->type() == QgsProcessingParameterVectorLayer::typeName() ? static_cast<QgsProcessingParameterVectorLayer *>( mParameter.get() )->dataTypes()
+                                                                                                                                                                           : QList<int>() );
       bool acceptable = false;
       switch ( QgsWkbTypes::geometryType( u.wkbType ) )
       {
@@ -444,22 +437,22 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
           break;
 
         case Qgis::GeometryType::Point:
-          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPoint ) ) )
+          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPoint ) ) )
             acceptable = true;
           break;
 
         case Qgis::GeometryType::Line:
-          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) ) )
+          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) ) )
             acceptable = true;
           break;
 
         case Qgis::GeometryType::Polygon:
-          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon ) ) )
+          if ( dataTypes.isEmpty() || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon ) ) )
             acceptable = true;
           break;
 
         case Qgis::GeometryType::Null:
-          if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) )
+          if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Vector ) ) )
             acceptable = true;
           break;
       }
@@ -474,8 +467,8 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
       return u.uri;
     else if ( mParameter->type() == QgsProcessingParameterMapLayer::typeName() )
     {
-      QList< int > dataTypes = static_cast< QgsProcessingParameterMapLayer * >( mParameter.get() )->dataTypes();
-      if ( dataTypes.isEmpty() || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::MapLayer ) ) )
+      QList<int> dataTypes = static_cast<QgsProcessingParameterMapLayer *>( mParameter.get() )->dataTypes();
+      if ( dataTypes.isEmpty() || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::MapLayer ) ) )
       {
         return u.uri;
       }
@@ -488,17 +481,17 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
             return u.uri;
 
           case Qgis::GeometryType::Point:
-            if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPoint ) ) )
+            if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPoint ) ) )
               return u.uri;
             break;
 
           case Qgis::GeometryType::Line:
-            if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) ) )
+            if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) ) )
               return u.uri;
             break;
 
           case Qgis::GeometryType::Polygon:
-            if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon ) ) )
+            if ( dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) || dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon ) ) )
               return u.uri;
             break;
 
@@ -507,10 +500,10 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
         }
       }
       else if ( u.layerType == QLatin1String( "raster" ) && u.providerKey == QLatin1String( "gdal" )
-                && dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Raster ) ) )
+                && dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Raster ) ) )
         return u.uri;
       else if ( u.layerType == QLatin1String( "mesh" ) && u.providerKey == QLatin1String( "mdal" )
-                && dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Mesh ) ) )
+                && dataTypes.contains( static_cast<int>( Qgis::ProcessingSourceType::Mesh ) ) )
         return u.uri;
     }
   }
@@ -521,11 +514,11 @@ QString QgsProcessingMapLayerComboBox::compatibleUriFromMimeData( const QMimeDat
   QStringList rawPaths;
   if ( data->hasUrls() )
   {
-    const QList< QUrl > urls = data->urls();
+    const QList<QUrl> urls = data->urls();
     rawPaths.reserve( urls.count() );
     for ( const QUrl &url : urls )
     {
-      const QString local =  url.toLocalFile();
+      const QString local = url.toLocalFile();
       if ( !rawPaths.contains( local ) )
         rawPaths.append( local );
     }
@@ -603,9 +596,9 @@ void QgsProcessingMapLayerComboBox::onLayerChanged( QgsMapLayer *layer )
 {
   if ( mUseSelectionCheckBox && mParameter->type() == QgsProcessingParameterFeatureSource::typeName() )
   {
-    if ( QgsVectorLayer *vl = qobject_cast< QgsVectorLayer * >( layer ) )
+    if ( QgsVectorLayer *vl = qobject_cast<QgsVectorLayer *>( layer ) )
     {
-      if ( QgsVectorLayer *prevLayer = qobject_cast< QgsVectorLayer * >( mPrevLayer ) )
+      if ( QgsVectorLayer *prevLayer = qobject_cast<QgsVectorLayer *>( mPrevLayer ) )
       {
         disconnect( prevLayer, &QgsVectorLayer::selectionChanged, this, &QgsProcessingMapLayerComboBox::selectionChanged );
       }
@@ -634,7 +627,7 @@ void QgsProcessingMapLayerComboBox::showSourceOptions()
   {
     QgsProcessingFeatureSourceOptionsWidget *widget = new QgsProcessingFeatureSourceOptionsWidget();
     widget->setPanelTitle( tr( "%1 Options" ).arg( mParameter->description() ) );
-    widget->setLayer( qobject_cast< QgsVectorLayer * >( mCombo->currentLayer() ) );
+    widget->setLayer( qobject_cast<QgsVectorLayer *>( mCombo->currentLayer() ) );
 
     widget->setGeometryCheckMethod( mIsOverridingDefaultGeometryCheck, mGeometryCheck );
     widget->setFeatureLimit( mFeatureLimit );
@@ -642,8 +635,7 @@ void QgsProcessingMapLayerComboBox::showSourceOptions()
 
     panel->openPanel( widget );
 
-    connect( widget, &QgsPanelWidget::widgetChanged, this, [ = ]
-    {
+    connect( widget, &QgsPanelWidget::widgetChanged, this, [=] {
       bool changed = false;
       changed = changed | ( widget->featureLimit() != mFeatureLimit );
       changed = changed | ( widget->filterExpression() != mFilterExpression );
@@ -675,7 +667,7 @@ void QgsProcessingMapLayerComboBox::selectFromFile()
     path = settings.value( QStringLiteral( "/Processing/LastInputPath" ) ).toString();
 
   QString filter;
-  if ( const QgsFileFilterGenerator *generator = dynamic_cast< const QgsFileFilterGenerator * >( mParameter.get() ) )
+  if ( const QgsFileFilterGenerator *generator = dynamic_cast<const QgsFileFilterGenerator *>( mParameter.get() ) )
     filter = generator->createFileFilter();
   else
     filter = QObject::tr( "All files (*.*)" );
@@ -698,12 +690,10 @@ void QgsProcessingMapLayerComboBox::browseForLayer()
 
     panel->openPanel( widget );
 
-    connect( widget, &QgsDataSourceSelectWidget::itemTriggered, this, [ = ]( const QgsMimeDataUtils::Uri & )
-    {
+    connect( widget, &QgsDataSourceSelectWidget::itemTriggered, this, [=]( const QgsMimeDataUtils::Uri & ) {
       widget->acceptPanel();
     } );
-    connect( widget, &QgsPanelWidget::panelAccepted, this, [ = ]()
-    {
+    connect( widget, &QgsPanelWidget::panelAccepted, this, [=]() {
       QgsProcessingContext context;
       if ( widget->uri().uri.isEmpty() )
         setValue( QVariant(), context );
@@ -716,5 +706,4 @@ void QgsProcessingMapLayerComboBox::browseForLayer()
 }
 
 
-
 ///@endcond
