@@ -17,6 +17,7 @@
 #include "qgsexception.h"
 #include "qgsdatasourceuri.h"
 #include "qgshanaconnection.h"
+#include "moc_qgshanaconnection.cpp"
 #include "qgshanaconnectionstringbuilder.h"
 #include "qgshanadatatypes.h"
 #include "qgshanadriver.h"
@@ -47,8 +48,7 @@ namespace
   {
     QMap<QString, bool> ret;
     DatabaseMetaDataUnicodeRef dmd = conn.getDatabaseMetaDataUnicode();
-    ResultSetRef rsStats = dmd->getStatistics( nullptr, schemaName.toStdU16String().c_str(),
-                           tableName.toStdU16String().c_str(), IndexType::UNIQUE, StatisticsAccuracy::ENSURE );
+    ResultSetRef rsStats = dmd->getStatistics( nullptr, schemaName.toStdU16String().c_str(), tableName.toStdU16String().c_str(), IndexType::UNIQUE, StatisticsAccuracy::ENSURE );
     QMap<QString, QStringList> compositeKeys;
     while ( rsStats->next() )
     {
@@ -76,7 +76,7 @@ namespace
   int getSrid( PreparedStatementRef &stmt )
   {
     int srid = -1;
-    ResultSetRef rsSrid = stmt->executeQuery( );
+    ResultSetRef rsSrid = stmt->executeQuery();
     while ( rsSrid->next() )
     {
       Int value = rsSrid->getInt( 1 );
@@ -93,7 +93,7 @@ namespace
     rsSrid->close();
     return srid;
   }
-}
+} // namespace
 
 QgsField AttributeField::toQgsField() const
 {
@@ -178,7 +178,7 @@ QgsField AttributeField::toQgsField() const
 static const uint8_t CREDENTIALS_INPUT_MAX_ATTEMPTS = 5;
 static const int GEOMETRIES_SELECT_LIMIT = 10;
 
-QgsHanaConnection::QgsHanaConnection( ConnectionRef connection,  const QgsDataSourceUri &uri )
+QgsHanaConnection::QgsHanaConnection( ConnectionRef connection, const QgsDataSourceUri &uri )
   : mConnection( connection )
   , mUri( uri )
 {
@@ -224,10 +224,7 @@ QgsHanaConnection *QgsHanaConnection::createConnection( const QgsDataSourceUri &
     conn->setAutoCommit( false );
     QString message;
 
-    auto connect = []( ConnectionRef & conn,
-                       const QgsDataSourceUri & uri,
-                       QString & errorMessage )
-    {
+    auto connect = []( ConnectionRef &conn, const QgsDataSourceUri &uri, QString &errorMessage ) {
       try
       {
         QgsHanaConnectionStringBuilder sb( uri );
@@ -405,7 +402,7 @@ QVariant QgsHanaConnection::executeScalar( const QString &sql )
     if ( resultSet->next() )
       res = resultSet->getValue( 1 );
     resultSet->close();
-    return  res;
+    return res;
   }
   catch ( const Exception &ex )
   {
@@ -423,7 +420,7 @@ QVariant QgsHanaConnection::executeScalar( const QString &sql, const QVariantLis
     if ( resultSet->next() )
       res = resultSet->getValue( 1 );
     resultSet->close();
-    return  res;
+    return res;
   }
   catch ( const Exception &ex )
   {
@@ -577,44 +574,46 @@ QVector<QgsHanaLayerProperty> QgsHanaConnection::getLayers(
   const QString &schemaName,
   bool allowGeometrylessTables,
   bool userTablesOnly,
-  const std::function<bool( const QgsHanaLayerProperty &layer )> &layerFilter )
+  const std::function<bool( const QgsHanaLayerProperty &layer )> &layerFilter
+)
 {
   const QString schema = mUri.schema().isEmpty() ? schemaName : mUri.schema();
   const QString sqlSchemaFilter = QStringLiteral(
-                                    "SELECT DISTINCT(SCHEMA_NAME) FROM SYS.EFFECTIVE_PRIVILEGES WHERE "
-                                    "OBJECT_TYPE IN ('SCHEMA', 'TABLE', 'VIEW') AND "
-                                    "SCHEMA_NAME LIKE ? AND "
-                                    "SCHEMA_NAME NOT LIKE_REGEXPR 'SYS|_SYS.*|UIS|SAP_XS|SAP_REST|HANA_XS' AND "
-                                    "PRIVILEGE IN ('SELECT', 'CREATE ANY') AND "
-                                    "USER_NAME = CURRENT_USER AND IS_VALID = 'TRUE'" );
+    "SELECT DISTINCT(SCHEMA_NAME) FROM SYS.EFFECTIVE_PRIVILEGES WHERE "
+    "OBJECT_TYPE IN ('SCHEMA', 'TABLE', 'VIEW') AND "
+    "SCHEMA_NAME LIKE ? AND "
+    "SCHEMA_NAME NOT LIKE_REGEXPR 'SYS|_SYS.*|UIS|SAP_XS|SAP_REST|HANA_XS' AND "
+    "PRIVILEGE IN ('SELECT', 'CREATE ANY') AND "
+    "USER_NAME = CURRENT_USER AND IS_VALID = 'TRUE'"
+  );
 
   const QString sqlOwnerFilter = userTablesOnly ? QStringLiteral( "OWNER_NAME = CURRENT_USER" ) : QStringLiteral( "OWNER_NAME IS NOT NULL" );
 
-  const QString sqlDataTypeFilter = !allowGeometrylessTables ? QStringLiteral( "DATA_TYPE_NAME IN ('ST_GEOMETRY','ST_POINT')" ) :
-                                    QStringLiteral( "DATA_TYPE_NAME IS NOT NULL" );
+  const QString sqlDataTypeFilter = !allowGeometrylessTables ? QStringLiteral( "DATA_TYPE_NAME IN ('ST_GEOMETRY','ST_POINT')" ) : QStringLiteral( "DATA_TYPE_NAME IS NOT NULL" );
 
   const QString sqlTables = QStringLiteral(
-                              "SELECT SCHEMA_NAME, TABLE_NAME, COLUMN_NAME, DATA_TYPE_NAME, TABLE_COMMENTS FROM "
-                              "(SELECT * FROM SYS.TABLE_COLUMNS WHERE "
-                              "TABLE_OID IN (SELECT OBJECT_OID FROM OWNERSHIP WHERE OBJECT_TYPE = 'TABLE' AND %1) AND "
-                              "SCHEMA_NAME IN (%2) AND %3) "
-                              "INNER JOIN "
-                              "(SELECT TABLE_OID AS TABLE_OID_2, COMMENTS AS TABLE_COMMENTS FROM SYS.TABLES WHERE IS_USER_DEFINED_TYPE = 'FALSE') "
-                              "ON TABLE_OID = TABLE_OID_2" );
+    "SELECT SCHEMA_NAME, TABLE_NAME, COLUMN_NAME, DATA_TYPE_NAME, TABLE_COMMENTS FROM "
+    "(SELECT * FROM SYS.TABLE_COLUMNS WHERE "
+    "TABLE_OID IN (SELECT OBJECT_OID FROM OWNERSHIP WHERE OBJECT_TYPE = 'TABLE' AND %1) AND "
+    "SCHEMA_NAME IN (%2) AND %3) "
+    "INNER JOIN "
+    "(SELECT TABLE_OID AS TABLE_OID_2, COMMENTS AS TABLE_COMMENTS FROM SYS.TABLES WHERE IS_USER_DEFINED_TYPE = 'FALSE') "
+    "ON TABLE_OID = TABLE_OID_2"
+  );
 
   const QString sqlViews = QStringLiteral(
-                             "SELECT SCHEMA_NAME, VIEW_NAME, COLUMN_NAME, DATA_TYPE_NAME, VIEW_COMMENTS FROM "
-                             "(SELECT * FROM SYS.VIEW_COLUMNS WHERE "
-                             "VIEW_OID IN (SELECT OBJECT_OID FROM OWNERSHIP WHERE OBJECT_TYPE = 'VIEW' AND %1) AND "
-                             "SCHEMA_NAME IN (%2) AND %3) "
-                             "INNER JOIN "
-                             "(SELECT VIEW_OID AS VIEW_OID_2, COMMENTS AS VIEW_COMMENTS FROM SYS.VIEWS) "
-                             "ON VIEW_OID = VIEW_OID_2" );
+    "SELECT SCHEMA_NAME, VIEW_NAME, COLUMN_NAME, DATA_TYPE_NAME, VIEW_COMMENTS FROM "
+    "(SELECT * FROM SYS.VIEW_COLUMNS WHERE "
+    "VIEW_OID IN (SELECT OBJECT_OID FROM OWNERSHIP WHERE OBJECT_TYPE = 'VIEW' AND %1) AND "
+    "SCHEMA_NAME IN (%2) AND %3) "
+    "INNER JOIN "
+    "(SELECT VIEW_OID AS VIEW_OID_2, COMMENTS AS VIEW_COMMENTS FROM SYS.VIEWS) "
+    "ON VIEW_OID = VIEW_OID_2"
+  );
 
   QMultiHash<QPair<QString, QString>, QgsHanaLayerProperty> layers;
 
-  auto addLayers = [&]( const QString & sql, bool isView )
-  {
+  auto addLayers = [&]( const QString &sql, bool isView ) {
     PreparedStatementRef stmt = mConnection->prepareStatement( QgsHanaUtils::toUtf16( sql ) );
     stmt->setNString( 1, NString( schema.isEmpty() ? u"%" : schema.toStdU16String() ) );
     QgsHanaResultSetRef rsLayers = QgsHanaResultSet::create( stmt );
@@ -686,7 +685,8 @@ QVector<QgsHanaLayerProperty> QgsHanaConnection::getLayersFull(
   const QString &schemaName,
   bool allowGeometrylessTables,
   bool userTablesOnly,
-  const std::function<bool( const QgsHanaLayerProperty &layer )> &layerFilter )
+  const std::function<bool( const QgsHanaLayerProperty &layer )> &layerFilter
+)
 {
   QVector<QgsHanaLayerProperty> layers = getLayers( schemaName, allowGeometrylessTables, userTablesOnly, layerFilter );
   // We cannot use a range-based for loop as layers are modified in readLayerInfo.
@@ -711,13 +711,12 @@ void QgsHanaConnection::readLayerInfo( QgsHanaLayerProperty &layerProperty )
   }
 }
 
-void QgsHanaConnection::readQueryFields( const QString &schemaName, const QString &sql,
-    const std::function<void( const AttributeField &field )> &callback )
+void QgsHanaConnection::readQueryFields( const QString &schemaName, const QString &sql, const std::function<void( const AttributeField &field )> &callback )
 {
   QMap<QString, QMap<QString, QString>> clmComments;
   auto getColumnComments = [&clmComments, &conn = mConnection](
-                             const QString & schemaName, const QString & tableName, const QString & columnName )
-  {
+                             const QString &schemaName, const QString &tableName, const QString &columnName
+                           ) {
     if ( schemaName.isEmpty() || tableName.isEmpty() || columnName.isEmpty() )
       return QString();
     const QString key = QStringLiteral( "%1.%2" ).arg( QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ) );
@@ -742,8 +741,8 @@ void QgsHanaConnection::readQueryFields( const QString &schemaName, const QStrin
 
   QMap<QString, QMap<QString, bool>> clmUniqueness;
   auto isColumnUnique = [&clmUniqueness, &conn = mConnection](
-                          const QString & schemaName, const QString & tableName, const QString & columnName )
-  {
+                          const QString &schemaName, const QString &tableName, const QString &columnName
+                        ) {
     if ( schemaName.isEmpty() || tableName.isEmpty() || columnName.isEmpty() )
       return false;
     const QString key = QStringLiteral( "%1.%2" ).arg( QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ) );
@@ -800,13 +799,12 @@ void QgsHanaConnection::readQueryFields( const QString &schemaName, const QStrin
 void QgsHanaConnection::readTableFields( const QString &schemaName, const QString &tableName, const std::function<void( const AttributeField &field )> &callback )
 {
   QMap<QString, QMap<QString, bool>> clmAutoIncrement;
-  auto isColumnAutoIncrement = [&]( const QString & columnName )
-  {
+  auto isColumnAutoIncrement = [&]( const QString &columnName ) {
     const QString key = QStringLiteral( "%1.%2" ).arg( schemaName, tableName );
     if ( !clmAutoIncrement.contains( key ) )
     {
       QString sql = QStringLiteral( "SELECT * FROM %1.%2" )
-                    .arg( QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ) );
+                      .arg( QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ) );
       PreparedStatementRef stmt = prepareStatement( sql );
       ResultSetMetaDataUnicodeRef rsmd = stmt->getMetaDataUnicode();
       for ( unsigned short i = 1; i <= rsmd->getColumnCount(); ++i )
@@ -820,8 +818,7 @@ void QgsHanaConnection::readTableFields( const QString &schemaName, const QStrin
   };
 
   QMap<QString, QMap<QString, bool>> clmUniqueness;
-  auto isColumnUnique = [&]( const QString & columnName )
-  {
+  auto isColumnUnique = [&]( const QString &columnName ) {
     const QString key = QStringLiteral( "%1.%2" ).arg( schemaName, tableName );
     if ( !clmUniqueness.contains( key ) )
       clmUniqueness.insert( key, getColumnsUniqueness( *mConnection, schemaName, tableName ) );
@@ -834,26 +831,23 @@ void QgsHanaConnection::readTableFields( const QString &schemaName, const QStrin
     while ( rsColumns->next() )
     {
       AttributeField field;
-      field.schemaName = rsColumns->getString( 2/*TABLE_SCHEM*/ );
-      field.tableName = rsColumns->getString( 3/*TABLE_NAME*/ );
-      field.name = rsColumns->getString( 4/*COLUMN_NAME*/ );
-      field.type = QgsHanaDataTypeUtils::fromInt( rsColumns->getShort( 5/*DATA_TYPE*/ ) );
-      field.typeName =  rsColumns->getString( 6/*TYPE_NAME*/ );
+      field.schemaName = rsColumns->getString( 2 /*TABLE_SCHEM*/ );
+      field.tableName = rsColumns->getString( 3 /*TABLE_NAME*/ );
+      field.name = rsColumns->getString( 4 /*COLUMN_NAME*/ );
+      field.type = QgsHanaDataTypeUtils::fromInt( rsColumns->getShort( 5 /*DATA_TYPE*/ ) );
+      field.typeName = rsColumns->getString( 6 /*TYPE_NAME*/ );
       if ( field.type == QgsHanaDataType::Unknown )
         throw QgsHanaException( QString( "Type of the column '%1' is unknown" ).arg( field.name ) );
-      field.size = rsColumns->getInt( 7/*COLUMN_SIZE*/ );
-      field.precision = static_cast<int>( rsColumns->getShort( 9/*DECIMAL_DIGITS*/ ) );
-      field.isSigned = field.type == QgsHanaDataType::SmallInt || field.type == QgsHanaDataType::Integer ||
-                       field.type == QgsHanaDataType::BigInt || field.type == QgsHanaDataType::Decimal ||
-                       field.type == QgsHanaDataType::Numeric || field.type == QgsHanaDataType::Real ||
-                       field.type == QgsHanaDataType::Float || field.type == QgsHanaDataType::Double;
-      QString isNullable = rsColumns->getString( 18/*IS_NULLABLE*/ );
+      field.size = rsColumns->getInt( 7 /*COLUMN_SIZE*/ );
+      field.precision = static_cast<int>( rsColumns->getShort( 9 /*DECIMAL_DIGITS*/ ) );
+      field.isSigned = field.type == QgsHanaDataType::SmallInt || field.type == QgsHanaDataType::Integer || field.type == QgsHanaDataType::BigInt || field.type == QgsHanaDataType::Decimal || field.type == QgsHanaDataType::Numeric || field.type == QgsHanaDataType::Real || field.type == QgsHanaDataType::Float || field.type == QgsHanaDataType::Double;
+      QString isNullable = rsColumns->getString( 18 /*IS_NULLABLE*/ );
       field.isNullable = ( isNullable == QLatin1String( "YES" ) || isNullable == QLatin1String( "TRUE" ) );
       field.isAutoIncrement = isColumnAutoIncrement( field.name );
       field.isUnique = isColumnUnique( field.name );
       if ( field.type == QgsHanaDataType::Geometry )
         field.srid = getColumnSrid( schemaName, tableName, field.name );
-      field.comment = rsColumns->getString( 12/*REMARKS*/ );
+      field.comment = rsColumns->getString( 12 /*REMARKS*/ );
 
       callback( field );
     }
@@ -869,7 +863,7 @@ QVector<QgsHanaSchemaProperty> QgsHanaConnection::getSchemas( const QString &own
   QString sql = QStringLiteral( "SELECT SCHEMA_NAME, SCHEMA_OWNER FROM SYS.SCHEMAS WHERE "
                                 "HAS_PRIVILEGES = 'TRUE' AND %1 AND "
                                 "SCHEMA_NAME NOT LIKE_REGEXPR 'SYS|_SYS.*|UIS|SAP_XS|SAP_REST|HANA_XS|XSSQLCC_'" )
-                .arg( !ownerName.isEmpty() ? QStringLiteral( "SCHEMA_OWNER = ?" ) : QStringLiteral( "SCHEMA_OWNER IS NOT NULL" ) );
+                  .arg( !ownerName.isEmpty() ? QStringLiteral( "SCHEMA_OWNER = ?" ) : QStringLiteral( "SCHEMA_OWNER IS NOT NULL" ) );
 
   QVector<QgsHanaSchemaProperty> list;
 
@@ -881,7 +875,7 @@ QVector<QgsHanaSchemaProperty> QgsHanaConnection::getSchemas( const QString &own
     QgsHanaResultSetRef rsSchemas = QgsHanaResultSet::create( stmt );
     while ( rsSchemas->next() )
     {
-      list.push_back( {rsSchemas->getString( 1 ), rsSchemas->getString( 2 )} );
+      list.push_back( { rsSchemas->getString( 1 ), rsSchemas->getString( 2 ) } );
     }
     rsSchemas->close();
   }
@@ -898,9 +892,7 @@ QStringList QgsHanaConnection::getLayerPrimaryKey( const QString &schemaName, co
   try
   {
     DatabaseMetaDataUnicodeRef dbmd = mConnection->getDatabaseMetaDataUnicode();
-    ResultSetRef rsPrimaryKeys = dbmd->getPrimaryKeys( nullptr,
-                                 QgsHanaUtils::toUtf16( schemaName ),
-                                 QgsHanaUtils::toUtf16( tableName ) );
+    ResultSetRef rsPrimaryKeys = dbmd->getPrimaryKeys( nullptr, QgsHanaUtils::toUtf16( schemaName ), QgsHanaUtils::toUtf16( tableName ) );
     QMap<int, QString> pos2Name;
     while ( rsPrimaryKeys->next() )
     {
@@ -926,12 +918,11 @@ QStringList QgsHanaConnection::getPrimaryKeyCandidates( const QgsHanaLayerProper
   QgsHanaResultSetRef rsColumns = getColumns( layerProperty.schemaName, layerProperty.tableName, QStringLiteral( "%" ) );
   while ( rsColumns->next() )
   {
-    QgsHanaDataType dataType = QgsHanaDataTypeUtils::fromInt( rsColumns->getValue( 5/*DATA_TYPE */ ).toInt() );
+    QgsHanaDataType dataType = QgsHanaDataTypeUtils::fromInt( rsColumns->getValue( 5 /*DATA_TYPE */ ).toInt() );
     // We exclude ST_GEOMETRY, REAL_VECTOR and LOB columns
-    if ( dataType == QgsHanaDataType::Geometry || dataType == QgsHanaDataType::RealVector ||
-         dataType == QgsHanaDataType::LongVarBinary || dataType == QgsHanaDataType::LongVarChar || dataType == QgsHanaDataType::WLongVarChar )
+    if ( dataType == QgsHanaDataType::Geometry || dataType == QgsHanaDataType::RealVector || dataType == QgsHanaDataType::LongVarBinary || dataType == QgsHanaDataType::LongVarChar || dataType == QgsHanaDataType::WLongVarChar )
       continue;
-    ret << rsColumns->getValue( 4/*COLUMN_NAME */ ).toString();
+    ret << rsColumns->getValue( 4 /*COLUMN_NAME */ ).toString();
   }
   rsColumns->close();
   return ret;
@@ -944,10 +935,12 @@ Qgis::WkbType QgsHanaConnection::getColumnGeometryType( const QString &querySour
 
   Qgis::WkbType ret = Qgis::WkbType::Unknown;
   QString sql = QStringLiteral( "SELECT upper(%1.ST_GeometryType()), %1.ST_Is3D(), %1.ST_IsMeasured() FROM %2 "
-                                "WHERE %1 IS NOT NULL LIMIT %3" ).arg(
-                  QgsHanaUtils::quotedIdentifier( columnName ),
-                  querySource,
-                  QString::number( GEOMETRIES_SELECT_LIMIT ) );
+                                "WHERE %1 IS NOT NULL LIMIT %3" )
+                  .arg(
+                    QgsHanaUtils::quotedIdentifier( columnName ),
+                    querySource,
+                    QString::number( GEOMETRIES_SELECT_LIMIT )
+                  );
 
   try
   {
@@ -956,7 +949,8 @@ Qgis::WkbType QgsHanaConnection::getColumnGeometryType( const QString &querySour
     while ( rsGeomInfo->next() )
     {
       Qgis::WkbType geomType = QgsWkbTypes::singleType( QgsHanaUtils::toWkbType(
-                                 rsGeomInfo->getString( 1 ), rsGeomInfo->getInt( 2 ), rsGeomInfo->getInt( 3 ) ) );
+        rsGeomInfo->getString( 1 ), rsGeomInfo->getInt( 2 ), rsGeomInfo->getInt( 3 )
+      ) );
       if ( geomType == Qgis::WkbType::Unknown )
         continue;
       if ( ret == Qgis::WkbType::Unknown )
@@ -979,8 +973,7 @@ Qgis::WkbType QgsHanaConnection::getColumnGeometryType( const QString &querySour
 
 Qgis::WkbType QgsHanaConnection::getColumnGeometryType( const QString &schemaName, const QString &tableName, const QString &columnName )
 {
-  QString querySource = QStringLiteral( "%1.%2" ).arg( QgsHanaUtils::quotedIdentifier( schemaName ),
-                        QgsHanaUtils::quotedIdentifier( tableName ) );
+  QString querySource = QStringLiteral( "%1.%2" ).arg( QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ) );
   return getColumnGeometryType( querySource, columnName );
 }
 
@@ -1019,7 +1012,7 @@ int QgsHanaConnection::getColumnSrid( const QString &schemaName, const QString &
   try
   {
     PreparedStatementRef stmt = mConnection->prepareStatement( "SELECT SRS_ID FROM SYS.ST_GEOMETRY_COLUMNS "
-                                "WHERE SCHEMA_NAME = ? AND TABLE_NAME = ? AND COLUMN_NAME = ?" );
+                                                               "WHERE SCHEMA_NAME = ? AND TABLE_NAME = ? AND COLUMN_NAME = ?" );
     stmt->setNString( 1, NString( schemaName.toStdU16String() ) );
     stmt->setNString( 2, NString( tableName.toStdU16String() ) );
     stmt->setNString( 3, NString( columnName.toStdU16String() ) );
@@ -1028,10 +1021,7 @@ int QgsHanaConnection::getColumnSrid( const QString &schemaName, const QString &
     if ( srid == -1 )
     {
       QString sql = QStringLiteral( "SELECT %1.ST_SRID() FROM %2.%3 WHERE %1 IS NOT NULL LIMIT %4" )
-                    .arg( QgsHanaUtils::quotedIdentifier( columnName ),
-                          QgsHanaUtils::quotedIdentifier( schemaName ),
-                          QgsHanaUtils::quotedIdentifier( tableName ),
-                          QString::number( GEOMETRIES_SELECT_LIMIT ) );
+                      .arg( QgsHanaUtils::quotedIdentifier( columnName ), QgsHanaUtils::quotedIdentifier( schemaName ), QgsHanaUtils::quotedIdentifier( tableName ), QString::number( GEOMETRIES_SELECT_LIMIT ) );
       stmt = mConnection->prepareStatement( QgsHanaUtils::toUtf16( sql ) );
       srid = getSrid( stmt );
     }
@@ -1052,9 +1042,7 @@ int QgsHanaConnection::getColumnSrid( const QString &sql, const QString &columnN
   try
   {
     QString query = QStringLiteral( "SELECT %1.ST_SRID() FROM (%2) WHERE %1 IS NOT NULL LIMIT %3" )
-                    .arg( QgsHanaUtils::quotedIdentifier( columnName ),
-                          sql,
-                          QString::number( GEOMETRIES_SELECT_LIMIT ) );
+                      .arg( QgsHanaUtils::quotedIdentifier( columnName ), sql, QString::number( GEOMETRIES_SELECT_LIMIT ) );
     PreparedStatementRef stmt = mConnection->prepareStatement( QgsHanaUtils::toUtf16( query ) );
     return getSrid( stmt );
   }
@@ -1069,8 +1057,7 @@ QgsHanaResultSetRef QgsHanaConnection::getColumns( const QString &schemaName, co
   try
   {
     DatabaseMetaDataUnicodeRef metadata = mConnection->getDatabaseMetaDataUnicode();
-    QgsHanaResultSetRef ret( new QgsHanaResultSet( metadata->getColumns( nullptr,
-                             QgsHanaUtils::toUtf16( schemaName ), QgsHanaUtils::toUtf16( tableName ), QgsHanaUtils::toUtf16( fieldName ) ) ) );
+    QgsHanaResultSetRef ret( new QgsHanaResultSet( metadata->getColumns( nullptr, QgsHanaUtils::toUtf16( schemaName ), QgsHanaUtils::toUtf16( tableName ), QgsHanaUtils::toUtf16( fieldName ) ) ) );
     return ret;
   }
   catch ( const Exception &ex )
@@ -1079,10 +1066,10 @@ QgsHanaResultSetRef QgsHanaConnection::getColumns( const QString &schemaName, co
   }
 }
 
-bool  QgsHanaConnection::isTable( const QString &schemaName, const QString &tableName )
+bool QgsHanaConnection::isTable( const QString &schemaName, const QString &tableName )
 {
   QString sql = QStringLiteral( "SELECT COUNT(*) FROM SYS.TABLES WHERE SCHEMA_NAME = ? AND TABLE_NAME = ?" );
-  return executeCountQuery( sql, {schemaName, tableName } ) == 1;
+  return executeCountQuery( sql, { schemaName, tableName } ) == 1;
 }
 
 PreparedStatementRef QgsHanaConnection::createPreparedStatement( const QString &sql, const QVariantList &args )
