@@ -32,6 +32,7 @@
 #include "qgsproviderregistry.h"
 #include "qgswmsconnection.h"
 #include "qgswmssourceselect.h"
+#include "moc_qgswmssourceselect.cpp"
 #include "qgswmtsdimensions.h"
 #include "qgsnetworkaccessmanager.h"
 #include "qgswmscapabilities.h"
@@ -94,7 +95,6 @@ QgsWMSSourceSelect::QgsWMSSourceSelect( QWidget *parent, Qt::WindowFlags fl, Qgs
 
   if ( widgetMode() != QgsProviderRegistry::WidgetMode::Manager )
   {
-
     QHBoxLayout *layout = new QHBoxLayout;
 
     mFormats = QgsWmsProvider::supportedFormats();
@@ -154,7 +154,6 @@ QgsWMSSourceSelect::QgsWMSSourceSelect( QWidget *parent, Qt::WindowFlags fl, Qgs
 
   // set up the WMS connections we already know about
   populateConnectionList();
-
 }
 
 
@@ -210,7 +209,7 @@ void QgsWMSSourceSelect::btnEdit_clicked()
 void QgsWMSSourceSelect::btnDelete_clicked()
 {
   QString msg = tr( "Are you sure you want to remove the %1 connection and all associated settings?" )
-                .arg( cmbConnections->currentText() );
+                  .arg( cmbConnections->currentText() );
   QMessageBox::StandardButton result = QMessageBox::question( this, tr( "Confirm Delete" ), msg, QMessageBox::Yes | QMessageBox::No );
   if ( result == QMessageBox::Yes )
   {
@@ -229,8 +228,7 @@ void QgsWMSSourceSelect::btnSave_clicked()
 
 void QgsWMSSourceSelect::btnLoad_clicked()
 {
-  QString fileName = QFileDialog::getOpenFileName( this, tr( "Load Connections" ), QDir::homePath(),
-                     tr( "XML files (*.xml *.XML)" ) );
+  QString fileName = QFileDialog::getOpenFileName( this, tr( "Load Connections" ), QDir::homePath(), tr( "XML files (*.xml *.XML)" ) );
   if ( fileName.isEmpty() )
   {
     return;
@@ -248,7 +246,8 @@ QgsTreeWidgetItem *QgsWMSSourceSelect::createItem(
   QMap<int, QgsTreeWidgetItem *> &items,
   int &layerAndStyleCount,
   const QMap<int, int> &layerParents,
-  const QMap<int, QStringList> &layerParentNames )
+  const QMap<int, QStringList> &layerParentNames
+)
 {
   if ( items.contains( id ) )
     return items[id];
@@ -256,8 +255,8 @@ QgsTreeWidgetItem *QgsWMSSourceSelect::createItem(
   QgsTreeWidgetItem *item = nullptr;
   if ( layerParents.contains( id ) )
   {
-    int parent = layerParents[ id ];
-    item = new QgsTreeWidgetItem( createItem( parent, layerParentNames[ parent ], items, layerAndStyleCount, layerParents, layerParentNames ) );
+    int parent = layerParents[id];
+    item = new QgsTreeWidgetItem( createItem( parent, layerParentNames[parent], items, layerAndStyleCount, layerParents, layerParentNames ) );
   }
   else
     item = new QgsTreeWidgetItem( lstLayers );
@@ -265,11 +264,11 @@ QgsTreeWidgetItem *QgsWMSSourceSelect::createItem(
   item->setText( 0, QString::number( ++layerAndStyleCount ) );
   item->setText( 1, names[0].simplified() );
   item->setText( 2, names[1].simplified() );
-  item->setToolTip( 2, "<font color=black>" + names[1].simplified()  + "</font>" );
+  item->setToolTip( 2, "<font color=black>" + names[1].simplified() + "</font>" );
   item->setText( 3, names[2].simplified() );
-  item->setToolTip( 3, "<font color=black>" + names[2].simplified()  + "</font>" );
+  item->setToolTip( 3, "<font color=black>" + names[2].simplified() + "</font>" );
 
-  items[ id ] = item;
+  items[id] = item;
 
   return item;
 }
@@ -404,7 +403,7 @@ bool QgsWMSSourceSelect::populateLayerList( const QgsWmsCapabilities &capabiliti
             item->setData( Qt::UserRole + 1, format );
             item->setData( Qt::UserRole + 2, style.identifier );
             item->setData( Qt::UserRole + 3, setLink.tileMatrixSet );
-            item->setData( Qt::UserRole + 4, tileMatrixSets[ setLink.tileMatrixSet ].crs );
+            item->setData( Qt::UserRole + 4, tileMatrixSets[setLink.tileMatrixSet].crs );
             item->setData( Qt::UserRole + 5, l.title );
 
             lstTilesets->setItem( row, 0, item );
@@ -421,7 +420,7 @@ bool QgsWMSSourceSelect::populateLayerList( const QgsWmsCapabilities &capabiliti
             lstTilesets->setItem( row, 3, styleItem );
 
             lstTilesets->setItem( row, 4, new QTableWidgetItem( setLink.tileMatrixSet ) );
-            lstTilesets->setItem( row, 5, new QTableWidgetItem( tileMatrixSets[ setLink.tileMatrixSet ].crs ) );
+            lstTilesets->setItem( row, 5, new QTableWidgetItem( tileMatrixSets[setLink.tileMatrixSet].crs ) );
 
             if ( !mMimeMap.contains( format ) )
             {
@@ -469,6 +468,20 @@ void QgsWMSSourceSelect::btnConnect_clicked()
   QgsWMSConnection connection( cmbConnections->currentText() );
   mUri = connection.uri();
 
+  bool featureCountSet {};
+  if ( connection.uri().hasParam( QStringLiteral( "featureCount" ) ) )
+  {
+    connection.uri().param( QStringLiteral( "featureCount" ) ).toInt( &featureCountSet );
+    if ( featureCountSet )
+      mFeatureCount->setText( connection.uri().param( QStringLiteral( "featureCount" ) ) );
+  }
+
+  // Original default for old connections with no default feature count set
+  if ( !featureCountSet )
+  {
+    mFeatureCount->setText( QStringLiteral( "10" ) );
+  }
+
   QgsWmsSettings wmsSettings;
   if ( !wmsSettings.parseUri( mUri.encodedUri() ) )
   {
@@ -497,18 +510,16 @@ void QgsWMSSourceSelect::btnConnect_clicked()
     return;
   }
 
-  QgsWmsCapabilities caps { QgsProject::instance()->transformContext()  };
+  QgsWmsCapabilities caps { QgsProject::instance()->transformContext() };
   if ( !caps.parseResponse( capDownload.response(), wmsSettings.parserSettings() ) )
   {
-    QMessageBox msgBox( QMessageBox::Warning, tr( "WMS Provider" ),
-                        tr( "The server you are trying to connect to does not seem to be a WMS server. Please check the URL." ),
-                        QMessageBox::Ok, this );
+    QMessageBox msgBox( QMessageBox::Warning, tr( "WMS Provider" ), tr( "The server you are trying to connect to does not seem to be a WMS server. Please check the URL." ), QMessageBox::Ok, this );
     msgBox.setDetailedText( tr( "Instead of the capabilities string that was expected, the following response has been received:\n\n%1" ).arg( caps.lastError() ) );
     msgBox.exec();
     return;
   }
 
-  mFeatureCount->setEnabled( caps.identifyCapabilities() != QgsRasterInterface::NoCapabilities );
+  mFeatureCount->setEnabled( caps.identifyCapabilities() != Qgis::RasterInterfaceCapabilities( Qgis::RasterInterfaceCapability::NoCapabilities ) );
 
   populateLayerList( caps );
 }
@@ -539,7 +550,7 @@ void QgsWMSSourceSelect::addButtonClicked()
   {
     collectSelectedLayers( layers, styles, titles );
     crs = mCRS;
-    format = mFormats[ mImageFormatGroup->checkedId()].format;
+    format = mFormats[mImageFormatGroup->checkedId()].format;
 
     collectDimensions( layers, uri );
   }
@@ -550,7 +561,7 @@ void QgsWMSSourceSelect::addButtonClicked()
     layers = QStringList( item->data( Qt::UserRole + 0 ).toString() );
     format = item->data( Qt::UserRole + 1 ).toString();
     styles = QStringList( item->data( Qt::UserRole + 2 ).toString() );
-    crs    = item->data( Qt::UserRole + 4 ).toString();
+    crs = item->data( Qt::UserRole + 4 ).toString();
     titles = QStringList( item->data( Qt::UserRole + 5 ).toString() );
 
     uri.setParam( QStringLiteral( "tileMatrixSet" ), item->data( Qt::UserRole + 3 ).toStringList() );
@@ -600,6 +611,9 @@ void QgsWMSSourceSelect::addButtonClicked()
   uri.setParam( QStringLiteral( "crs" ), crs );
   QgsDebugMsgLevel( QStringLiteral( "crs=%2 " ).arg( crs ), 2 );
 
+  // Remove in case the default value from the connection settings
+  // is being overridden here
+  uri.removeParam( QStringLiteral( "featureCount" ) );
   if ( mFeatureCount->text().toInt() > 0 )
   {
     uri.setParam( QStringLiteral( "featureCount" ), mFeatureCount->text() );
@@ -619,15 +633,10 @@ void QgsWMSSourceSelect::addButtonClicked()
       individualUri.setParam( QStringLiteral( "styles" ), styles.at( i ) );
 
       Q_NOWARN_DEPRECATED_PUSH
-      emit addRasterLayer( individualUri.encodedUri(),
-                           titles.at( i ),
-                           QStringLiteral( "wms" ) );
+      emit addRasterLayer( individualUri.encodedUri(), titles.at( i ), QStringLiteral( "wms" ) );
       Q_NOWARN_DEPRECATED_POP
-      emit addLayer( Qgis::LayerType::Raster, individualUri.encodedUri(),
-                     titles.at( i ),
-                     QStringLiteral( "wms" ) );
+      emit addLayer( Qgis::LayerType::Raster, individualUri.encodedUri(), titles.at( i ), QStringLiteral( "wms" ) );
     }
-
   }
   else
   {
@@ -635,13 +644,9 @@ void QgsWMSSourceSelect::addButtonClicked()
     uri.setParam( QStringLiteral( "styles" ), styles );
 
     Q_NOWARN_DEPRECATED_PUSH
-    emit addRasterLayer( uri.encodedUri(),
-                         leLayerName->text().isEmpty() ? titles.join( QLatin1Char( '/' ) ) : leLayerName->text(),
-                         QStringLiteral( "wms" ) );
+    emit addRasterLayer( uri.encodedUri(), leLayerName->text().isEmpty() ? titles.join( QLatin1Char( '/' ) ) : leLayerName->text(), QStringLiteral( "wms" ) );
     Q_NOWARN_DEPRECATED_POP
-    emit addLayer( Qgis::LayerType::Raster, uri.encodedUri(),
-                   leLayerName->text().isEmpty() ? titles.join( QLatin1Char( '/' ) ) : leLayerName->text(),
-                   QStringLiteral( "wms" ) );
+    emit addLayer( Qgis::LayerType::Raster, uri.encodedUri(), leLayerName->text().isEmpty() ? titles.join( QLatin1Char( '/' ) ) : leLayerName->text(), QStringLiteral( "wms" ) );
   }
 }
 
@@ -787,7 +792,7 @@ void QgsWMSSourceSelect::applySelectionConstraints( QTreeWidgetItem *item )
       }
       else
       {
-        for ( QTreeWidgetItem *parent = item->parent(); parent;  parent = parent->parent() )
+        for ( QTreeWidgetItem *parent = item->parent(); parent; parent = parent->parent() )
         {
           parent->setSelected( false );
         }
@@ -882,7 +887,7 @@ void QgsWMSSourceSelect::lstLayers_itemSelectionChanged()
   labelCoordRefSys->setDisabled( mCRSs.isEmpty() );
   mCrsSelector->setDisabled( mCRSs.isEmpty() );
 
-  QList< QgsCoordinateReferenceSystem > crsFilter;
+  QList<QgsCoordinateReferenceSystem> crsFilter;
   crsFilter.reserve( mCRSs.size() );
   for ( const QString &crs : std::as_const( mCRSs ) )
   {
@@ -893,7 +898,6 @@ void QgsWMSSourceSelect::lstLayers_itemSelectionChanged()
 
   if ( !layers.isEmpty() && !mCRSs.isEmpty() )
   {
-
     // check whether current CRS is supported
     // if not, use one of the available CRS
     QString defaultCRS;
@@ -918,7 +922,6 @@ void QgsWMSSourceSelect::lstLayers_itemSelectionChanged()
       mCRS = defaultCRS;
       mCrsSelector->setCrs( QgsCoordinateReferenceSystem::fromOgcWmsCrs( mCRS ) );
     }
-
   }
   else if ( layers.isEmpty() || mCRSs.isEmpty() )
   {
@@ -972,7 +975,7 @@ void QgsWMSSourceSelect::updateButtons()
     //   disable tilesets, when layer are selected or no tilesets available
     lstLayers->setEnabled( true );
     tabServers->setTabEnabled( tabServers->indexOf( tabLayerOrder ), mLayerOrderTreeWidget->topLevelItemCount() > 0 );
-    tabServers->setTabEnabled( tabServers->indexOf( tabTilesets ), mLayerOrderTreeWidget->topLevelItemCount() == 0  && lstTilesets->rowCount() > 0 );
+    tabServers->setTabEnabled( tabServers->indexOf( tabTilesets ), mLayerOrderTreeWidget->topLevelItemCount() == 0 && lstTilesets->rowCount() > 0 );
     btnGrpImageEncoding->setEnabled( true );
   }
 
@@ -1075,11 +1078,9 @@ void QgsWMSSourceSelect::collectDimensions( QStringList &layers, QgsDataSourceUr
       for ( const QgsWmsDimensionProperty &dimension : std::as_const( layerProperty.dimensions ) )
       {
         // add temporal dimensions only
-        if ( dimension.name == QLatin1String( "time" ) ||
-             dimension.name == QLatin1String( "reference_time" ) )
+        if ( dimension.name == QLatin1String( "time" ) || dimension.name == QLatin1String( "reference_time" ) )
         {
-          QString name = dimension.name == QLatin1String( "time" ) ?
-                         QStringLiteral( "timeDimensionExtent" ) : QStringLiteral( "referenceTimeDimensionExtent" );
+          QString name = dimension.name == QLatin1String( "time" ) ? QStringLiteral( "timeDimensionExtent" ) : QStringLiteral( "referenceTimeDimensionExtent" );
 
           if ( !( uri.param( QLatin1String( "type" ) ) == QLatin1String( "wmst" ) ) )
             uri.setParam( QLatin1String( "type" ), QLatin1String( "wmst" ) );
@@ -1093,7 +1094,6 @@ void QgsWMSSourceSelect::collectDimensions( QStringList &layers, QgsDataSourceUr
         uri.setParam( QLatin1String( "temporalSource" ), QLatin1String( "provider" ) );
         uri.setParam( QLatin1String( "allowTemporalUpdates" ), QLatin1String( "true" ) );
       }
-
     }
   }
 }
@@ -1161,9 +1161,8 @@ void QgsWMSSourceSelect::cmbConnections_activated( int )
 
 void QgsWMSSourceSelect::filterLayers( const QString &searchText )
 {
-  std::function< void( QTreeWidgetItem *, bool ) > setChildrenVisible;
-  setChildrenVisible = [&setChildrenVisible]( QTreeWidgetItem * item, bool visible )
-  {
+  std::function<void( QTreeWidgetItem *, bool )> setChildrenVisible;
+  setChildrenVisible = [&setChildrenVisible]( QTreeWidgetItem *item, bool visible ) {
     for ( int i = 0; i < item->childCount(); ++i )
       setChildrenVisible( item->child( i ), visible );
     item->setHidden( !visible );
@@ -1236,7 +1235,7 @@ void QgsWMSSourceSelect::filterTiles( const QString &searchText )
 QString QgsWMSSourceSelect::descriptionForAuthId( const QString &authId )
 {
   if ( mCrsNames.contains( authId ) )
-    return mCrsNames[ authId ];
+    return mCrsNames[authId];
 
   QgsCoordinateReferenceSystem qgisSrs = QgsCoordinateReferenceSystem::fromOgcWmsCrs( authId );
   mCrsNames.insert( authId, qgisSrs.userFriendlyIdentifier() );
@@ -1315,7 +1314,6 @@ void QgsWMSSourceSelect::updateLayerOrderTab( const QStringList &newLayerList, c
       newItem->setText( 2, *titleListIt );
       mLayerOrderTreeWidget->addTopLevelItem( newItem );
     }
-
   }
 
   //check, if each layer style combination in the layer order tab is still in newLayerList / newStyleList
@@ -1354,7 +1352,8 @@ void QgsWMSSourceSelect::showHelp()
   QgsHelp::openHelp( QStringLiteral( "working_with_ogc/ogc_client_support.html" ) );
 }
 
-QgsWmsInterpretationComboBox::QgsWmsInterpretationComboBox( QWidget *parent ): QComboBox( parent )
+QgsWmsInterpretationComboBox::QgsWmsInterpretationComboBox( QWidget *parent )
+  : QComboBox( parent )
 {
   addItem( tr( "Default" ), QString() );
   addItem( QgsWmsInterpretationConverterMapTilerTerrainRGB::displayName(), QgsWmsInterpretationConverterMapTilerTerrainRGB::interpretationKey() );
@@ -1363,7 +1362,7 @@ QgsWmsInterpretationComboBox::QgsWmsInterpretationComboBox( QWidget *parent ): Q
 
 void QgsWmsInterpretationComboBox::setInterpretation( const QString &interpretationKey )
 {
-  if ( ! interpretationKey.isEmpty() )
+  if ( !interpretationKey.isEmpty() )
   {
     int index = findData( interpretationKey );
     if ( index == -1 )
@@ -1371,6 +1370,10 @@ void QgsWmsInterpretationComboBox::setInterpretation( const QString &interpretat
     else
       setCurrentIndex( index );
   }
+  else
+  {
+    setCurrentIndex( 0 );
+  }
 }
 
 QString QgsWmsInterpretationComboBox::interpretation() const
