@@ -10,9 +10,10 @@ the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 """
-__author__ = 'Alessandro Pasotti'
-__date__ = '05/08/2019'
-__copyright__ = 'Copyright 2019, The QGIS Project'
+
+__author__ = "Alessandro Pasotti"
+__date__ = "05/08/2019"
+__copyright__ = "Copyright 2019, The QGIS Project"
 
 import os
 import time
@@ -41,25 +42,25 @@ from qgis.core import (
 from qgis.testing import start_app
 
 
-class TestPyQgsProviderConnectionBase():
+class TestPyQgsProviderConnectionBase:
     # Provider test cases must define the string URI for the test
-    uri = ''
+    uri = ""
     # Provider test cases must define the provider name (e.g. "postgres" or "ogr")
-    providerKey = ''
+    providerKey = ""
 
     configuration = {}
 
-    defaultSchema = 'public'
+    defaultSchema = "public"
 
-    myNewTable = 'myNewTable'
-    myVeryNewTable = 'myVeryNewTable'
-    myUtf8Table = 'myUtf8\U0001f604Table'
-    geometryColumnName = 'geom'
+    myNewTable = "myNewTable"
+    myVeryNewTable = "myVeryNewTable"
+    myUtf8Table = "myUtf8\U0001f604Table"
+    geometryColumnName = "geom"
 
     # Provider test cases can define a schema and table name for SQL query layers test
     sqlVectorLayerSchema = None  # string, empty string for schema-less DBs (SQLite)
-    sqlVectorLayerTable = None   # string
-    sqlVectorLayerCrs = None   # string
+    sqlVectorLayerTable = None  # string
+    sqlVectorLayerCrs = None  # string
 
     @classmethod
     def setUpClass(cls):
@@ -74,7 +75,7 @@ class TestPyQgsProviderConnectionBase():
 
     def tearDown(self):
         report_file_path = f"{QDir.tempPath()}/qgistest.html"
-        with open(report_file_path, 'a') as report_file:
+        with open(report_file_path, "a") as report_file:
             report_file.write(self.report)
 
     def treat_date_as_string(self):
@@ -84,7 +85,8 @@ class TestPyQgsProviderConnectionBase():
 
     def getUniqueSchemaName(self, name):
         """This function must return a schema name with unique prefix/postfix,
-        if the tests are run simultaneously on the same machine by different CI instances"""
+        if the tests are run simultaneously on the same machine by different CI instances
+        """
         return name
 
     def _test_save_load(self, md, uri, configuration):
@@ -92,12 +94,12 @@ class TestPyQgsProviderConnectionBase():
 
         conn = md.createConnection(uri, configuration)
 
-        md.saveConnection(conn, 'qgis_test1')
+        md.saveConnection(conn, "qgis_test1")
         # Check that we retrieve the new connection
-        self.assertIn('qgis_test1', md.connections().keys())
-        self.assertIn('qgis_test1', md.dbConnections().keys())
+        self.assertIn("qgis_test1", md.connections().keys())
+        self.assertIn("qgis_test1", md.dbConnections().keys())
 
-        return md.connections()['qgis_test1']
+        return md.connections()["qgis_test1"]
 
     def _table_names(self, table_properties):
         """Return table default names from table property list"""
@@ -116,11 +118,14 @@ class TestPyQgsProviderConnectionBase():
         capabilities = conn.capabilities()
 
         # Schema operations
-        if (capabilities & QgsAbstractDatabaseProviderConnection.Capability.CreateSchema
+        if (
+            capabilities & QgsAbstractDatabaseProviderConnection.Capability.CreateSchema
             and capabilities & QgsAbstractDatabaseProviderConnection.Capability.Schemas
-                and capabilities & QgsAbstractDatabaseProviderConnection.Capability.DropSchema):
+            and capabilities
+            & QgsAbstractDatabaseProviderConnection.Capability.DropSchema
+        ):
 
-            myNewSchema = self.getUniqueSchemaName('myNewSchema')
+            myNewSchema = self.getUniqueSchemaName("myNewSchema")
             # Start clean
             if myNewSchema in conn.schemas():
                 conn.dropSchema(myNewSchema, True)
@@ -135,9 +140,12 @@ class TestPyQgsProviderConnectionBase():
                 conn.createSchema(myNewSchema)
 
             # Test rename
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.RenameSchema:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.RenameSchema
+            ):
                 # Rename
-                myVeryNewSchema = self.getUniqueSchemaName('myVeryNewSchema')
+                myVeryNewSchema = self.getUniqueSchemaName("myVeryNewSchema")
                 conn.renameSchema(myNewSchema, myVeryNewSchema)
                 schemas = conn.schemas()
                 self.assertIn(myVeryNewSchema, schemas)
@@ -153,7 +161,7 @@ class TestPyQgsProviderConnectionBase():
             self.assertNotIn(myNewSchema, schemas)
 
             # UTF8 schema
-            myUtf8NewSchema = self.getUniqueSchemaName('myUtf8\U0001f604NewSchema')
+            myUtf8NewSchema = self.getUniqueSchemaName("myUtf8\U0001f604NewSchema")
             conn.createSchema(myUtf8NewSchema)
             schemas = conn.schemas()
             conn.dropSchema(myUtf8NewSchema)
@@ -162,15 +170,24 @@ class TestPyQgsProviderConnectionBase():
 
         # Table operations
         schema = None
-        if (capabilities & QgsAbstractDatabaseProviderConnection.Capability.CreateVectorTable
+        if (
+            capabilities
+            & QgsAbstractDatabaseProviderConnection.Capability.CreateVectorTable
             and capabilities & QgsAbstractDatabaseProviderConnection.Capability.Tables
-                and capabilities & QgsAbstractDatabaseProviderConnection.Capability.DropVectorTable):
+            and capabilities
+            & QgsAbstractDatabaseProviderConnection.Capability.DropVectorTable
+        ):
 
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.CreateSchema:
-                schema = self.getUniqueSchemaName('myNewSchema')
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.CreateSchema
+            ):
+                schema = self.getUniqueSchemaName("myNewSchema")
                 conn.createSchema(schema)
 
-            elif capabilities & QgsAbstractDatabaseProviderConnection.Capability.Schemas:
+            elif (
+                capabilities & QgsAbstractDatabaseProviderConnection.Capability.Schemas
+            ):
                 schema = self.getUniqueSchemaName(self.defaultSchema)
 
             # Start clean
@@ -190,12 +207,16 @@ class TestPyQgsProviderConnectionBase():
             typ = QgsWkbTypes.Type.LineString
 
             # Create
-            conn.createVectorTable(schema, self.myNewTable, fields, typ, crs, True, options)
+            conn.createVectorTable(
+                schema, self.myNewTable, fields, typ, crs, True, options
+            )
             table_names = self._table_names(conn.tables(schema))
             self.assertIn(self.myNewTable, table_names)
 
             # Create UTF8 table
-            conn.createVectorTable(schema, self.myUtf8Table, fields, typ, crs, True, options)
+            conn.createVectorTable(
+                schema, self.myUtf8Table, fields, typ, crs, True, options
+            )
             table_names = self._table_names(conn.tables(schema))
             self.assertIn(self.myNewTable, table_names)
             self.assertIn(self.myUtf8Table, table_names)
@@ -205,10 +226,14 @@ class TestPyQgsProviderConnectionBase():
             self.assertIn(self.myNewTable, table_names)
 
             # insert something, because otherwise some databases cannot guess
-            if self.providerKey in ['hana', 'mssql', 'oracle']:
+            if self.providerKey in ["hana", "mssql", "oracle"]:
                 f = QgsFeature(fields)
-                f.setGeometry(QgsGeometry.fromWkt('LineString (-72.345 71.987, -80 80)'))
-                vl = QgsVectorLayer(conn.tableUri(schema, self.myNewTable), 'vl', self.providerKey)
+                f.setGeometry(
+                    QgsGeometry.fromWkt("LineString (-72.345 71.987, -80 80)")
+                )
+                vl = QgsVectorLayer(
+                    conn.tableUri(schema, self.myNewTable), "vl", self.providerKey
+                )
                 vl.dataProvider().addFeatures([f])
 
             # Check table information
@@ -220,61 +245,106 @@ class TestPyQgsProviderConnectionBase():
             self.assertEqual(table_property.geometryColumnCount(), 1)
 
             # with oracle line and curve have the same type, so it defaults to curve https://docs.oracle.com/database/121/SPATL/sdo_geometry-object-type.htm#SPATL494
-            line_wkb_type = QgsWkbTypes.Type.LineString if self.providerKey != 'oracle' else QgsWkbTypes.Type.CompoundCurve
+            line_wkb_type = (
+                QgsWkbTypes.Type.LineString
+                if self.providerKey != "oracle"
+                else QgsWkbTypes.Type.CompoundCurve
+            )
 
-            self.assertEqual(table_property.geometryColumnTypes()[0].wkbType, line_wkb_type)
+            self.assertEqual(
+                table_property.geometryColumnTypes()[0].wkbType, line_wkb_type
+            )
             cols = table_property.geometryColumnTypes()
             self.assertEqual(cols[0].crs, QgsCoordinateReferenceSystem.fromEpsgId(3857))
             self.assertEqual(table_property.defaultName(), self.myNewTable)
 
             # Check aspatial tables
-            conn.createVectorTable(schema, 'myNewAspatialTable', fields, QgsWkbTypes.Type.NoGeometry, crs, True, options)
-            table_properties = conn.tables(schema, QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial)
-            table_property = self._table_by_name(table_properties, 'myNewAspatialTable')
+            conn.createVectorTable(
+                schema,
+                "myNewAspatialTable",
+                fields,
+                QgsWkbTypes.Type.NoGeometry,
+                crs,
+                True,
+                options,
+            )
+            table_properties = conn.tables(
+                schema, QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial
+            )
+            table_property = self._table_by_name(table_properties, "myNewAspatialTable")
             self.assertIsNotNone(table_property)
             self.assertEqual(table_property.maxCoordinateDimensions(), 0)
-            self.assertEqual(table_property.tableName(), 'myNewAspatialTable')
+            self.assertEqual(table_property.tableName(), "myNewAspatialTable")
             self.assertEqual(table_property.geometryColumnCount(), 0)
-            self.assertEqual(table_property.geometryColumn(), '')
-            self.assertEqual(table_property.defaultName(), 'myNewAspatialTable')
+            self.assertEqual(table_property.geometryColumn(), "")
+            self.assertEqual(table_property.defaultName(), "myNewAspatialTable")
             cols = table_property.geometryColumnTypes()
             # We always return geom col types, even when there is no geometry
             self.assertEqual(cols[0].wkbType, QgsWkbTypes.Type.NoGeometry)
             self.assertFalse(cols[0].crs.isValid())
-            self.assertFalse(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Raster)
-            self.assertFalse(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Vector)
-            self.assertTrue(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial)
+            self.assertFalse(
+                table_property.flags()
+                & QgsAbstractDatabaseProviderConnection.TableFlag.Raster
+            )
+            self.assertFalse(
+                table_property.flags()
+                & QgsAbstractDatabaseProviderConnection.TableFlag.Vector
+            )
+            self.assertTrue(
+                table_property.flags()
+                & QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial
+            )
 
             # Check executeSql
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.ExecuteSql:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.ExecuteSql
+            ):
                 if schema:
-                    table = f"\"{schema}\".\"myNewAspatialTable\""
+                    table = f'"{schema}"."myNewAspatialTable"'
                 else:
-                    table = 'myNewAspatialTable'
+                    table = "myNewAspatialTable"
 
                 # MSSQL literal syntax for UTF8 requires 'N' prefix
                 # Oracle date time definition needs some prefix
-                sql = "INSERT INTO {} (\"string_t\", \"long_t\", \"double_t\", \"integer_t\", \"date_t\", \"datetime_t\", \"time_t\") VALUES ({}'QGIS Rocks - \U0001f604', 666, 1.234, 1234, {} '2019-07-08', {}, '12:00:13.00')".format(
-                    table, 'N' if self.providerKey == 'mssql' else '',
-                    "DATE" if self.providerKey == 'oracle' else '',
-                    "TIMESTAMP '2019-07-08 12:00:12'" if self.providerKey == 'oracle' else "'2019-07-08T12:00:12'"
+                sql = 'INSERT INTO {} ("string_t", "long_t", "double_t", "integer_t", "date_t", "datetime_t", "time_t") VALUES ({}\'QGIS Rocks - \U0001f604\', 666, 1.234, 1234, {} \'2019-07-08\', {}, \'12:00:13.00\')'.format(
+                    table,
+                    "N" if self.providerKey == "mssql" else "",
+                    "DATE" if self.providerKey == "oracle" else "",
+                    (
+                        "TIMESTAMP '2019-07-08 12:00:12'"
+                        if self.providerKey == "oracle"
+                        else "'2019-07-08T12:00:12'"
+                    ),
                 )
                 res = conn.executeSql(sql)
                 self.assertEqual(res, [])
-                sql = f"SELECT \"string_t\", \"long_t\", \"double_t\", \"integer_t\", \"date_t\", \"datetime_t\" FROM {table}"
+                sql = f'SELECT "string_t", "long_t", "double_t", "integer_t", "date_t", "datetime_t" FROM {table}'
                 res = conn.executeSql(sql)
 
                 expected_date = QtCore.QDate(2019, 7, 8)
 
                 # GPKG and spatialite have no type for time
                 if self.treat_date_as_string():
-                    expected_date = '2019-07-08'
+                    expected_date = "2019-07-08"
 
                 # Oracle DATE type contains date and time and so returns a QDateTime object
-                elif self.providerKey == 'oracle':
+                elif self.providerKey == "oracle":
                     expected_date = QtCore.QDateTime(QtCore.QDate(2019, 7, 8))
 
-                self.assertEqual(res, [['QGIS Rocks - \U0001f604', 666, 1.234, 1234, expected_date, QtCore.QDateTime(2019, 7, 8, 12, 0, 12)]])
+                self.assertEqual(
+                    res,
+                    [
+                        [
+                            "QGIS Rocks - \U0001f604",
+                            666,
+                            1.234,
+                            1234,
+                            expected_date,
+                            QtCore.QDateTime(2019, 7, 8, 12, 0, 12),
+                        ]
+                    ],
+                )
 
                 # Test column names
                 res = conn.execSql(sql)
@@ -285,8 +355,30 @@ class TestPyQgsProviderConnectionBase():
                     self.assertEqual(row_count, 1)
 
                 rows = res.rows()
-                self.assertEqual(rows, [['QGIS Rocks - \U0001f604', 666, 1.234, 1234, expected_date, QtCore.QDateTime(2019, 7, 8, 12, 0, 12)]])
-                self.assertEqual(res.columns(), ['string_t', 'long_t', 'double_t', 'integer_t', 'date_t', 'datetime_t'])
+                self.assertEqual(
+                    rows,
+                    [
+                        [
+                            "QGIS Rocks - \U0001f604",
+                            666,
+                            1.234,
+                            1234,
+                            expected_date,
+                            QtCore.QDateTime(2019, 7, 8, 12, 0, 12),
+                        ]
+                    ],
+                )
+                self.assertEqual(
+                    res.columns(),
+                    [
+                        "string_t",
+                        "long_t",
+                        "double_t",
+                        "integer_t",
+                        "date_t",
+                        "datetime_t",
+                    ],
+                )
 
                 self.assertEqual(res.fetchedRowCount(), 1)
 
@@ -311,38 +403,57 @@ class TestPyQgsProviderConnectionBase():
                 self.assertFalse(res.hasNextRow())
 
                 # Test time_t
-                sql = f"SELECT \"time_t\" FROM {table}"
+                sql = f'SELECT "time_t" FROM {table}'
                 res = conn.executeSql(sql)
 
                 # This does not work in MSSQL and returns a QByteArray, we have no way to know that it is a time
                 # value and there is no way we can convert it.
-                if self.providerKey != 'mssql':
-                    self.assertIn(res, ([[QtCore.QTime(12, 0, 13)]], [['12:00:13.00']]))
+                if self.providerKey != "mssql":
+                    self.assertIn(res, ([[QtCore.QTime(12, 0, 13)]], [["12:00:13.00"]]))
 
                 sql = "DELETE FROM {} WHERE \"string_t\" = {}'QGIS Rocks - \U0001f604'".format(
-                    table, 'N' if self.providerKey == 'mssql' else '')
+                    table, "N" if self.providerKey == "mssql" else ""
+                )
                 res = conn.executeSql(sql)
                 self.assertEqual(res, [])
-                sql = f"SELECT \"string_t\", \"integer_t\" FROM {table}"
+                sql = f'SELECT "string_t", "integer_t" FROM {table}'
                 res = conn.executeSql(sql)
                 self.assertEqual(res, [])
 
             # Check that we do NOT get the aspatial table when querying for vectors
-            table_names = self._table_names(conn.tables(schema, QgsAbstractDatabaseProviderConnection.TableFlag.Vector))
+            table_names = self._table_names(
+                conn.tables(
+                    schema, QgsAbstractDatabaseProviderConnection.TableFlag.Vector
+                )
+            )
             self.assertIn(self.myNewTable, table_names)
-            self.assertNotIn('myNewAspatialTable', table_names)
+            self.assertNotIn("myNewAspatialTable", table_names)
 
             # Query for rasters (in qgis_test schema or no schema for GPKG, spatialite has no support)
-            if self.providerKey not in ('spatialite', 'mssql', 'hana', 'oracle'):
-                table_properties = conn.tables('qgis_test', QgsAbstractDatabaseProviderConnection.TableFlag.Raster)
+            if self.providerKey not in ("spatialite", "mssql", "hana", "oracle"):
+                table_properties = conn.tables(
+                    "qgis_test", QgsAbstractDatabaseProviderConnection.TableFlag.Raster
+                )
                 # At least one raster should be there (except for spatialite)
                 self.assertGreaterEqual(len(table_properties), 1)
                 table_property = table_properties[0]
-                self.assertTrue(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Raster)
-                self.assertFalse(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Vector)
-                self.assertFalse(table_property.flags() & QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial)
+                self.assertTrue(
+                    table_property.flags()
+                    & QgsAbstractDatabaseProviderConnection.TableFlag.Raster
+                )
+                self.assertFalse(
+                    table_property.flags()
+                    & QgsAbstractDatabaseProviderConnection.TableFlag.Vector
+                )
+                self.assertFalse(
+                    table_property.flags()
+                    & QgsAbstractDatabaseProviderConnection.TableFlag.Aspatial
+                )
 
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.RenameVectorTable:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.RenameVectorTable
+            ):
                 # Rename
                 conn.renameVectorTable(schema, self.myNewTable, self.myVeryNewTable)
                 tables = self._table_names(conn.tables(schema))
@@ -361,30 +472,71 @@ class TestPyQgsProviderConnectionBase():
             # Spatial index
             spatial_index_exists = False
             # we don't initially know if a spatial index exists -- some formats may create them by default, others don't
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists:
-                spatial_index_exists = conn.spatialIndexExists(schema, self.myNewTable, self.geometryColumnName)
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.DeleteSpatialIndex:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists
+            ):
+                spatial_index_exists = conn.spatialIndexExists(
+                    schema, self.myNewTable, self.geometryColumnName
+                )
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.DeleteSpatialIndex
+            ):
                 if spatial_index_exists:
-                    conn.deleteSpatialIndex(schema, self.myNewTable, self.geometryColumnName)
-                if capabilities & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists:
-                    self.assertFalse(conn.spatialIndexExists(schema, self.myNewTable, self.geometryColumnName))
+                    conn.deleteSpatialIndex(
+                        schema, self.myNewTable, self.geometryColumnName
+                    )
+                if (
+                    capabilities
+                    & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists
+                ):
+                    self.assertFalse(
+                        conn.spatialIndexExists(
+                            schema, self.myNewTable, self.geometryColumnName
+                        )
+                    )
 
-            if capabilities & (QgsAbstractDatabaseProviderConnection.Capability.CreateSpatialIndex | QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists):
+            if capabilities & (
+                QgsAbstractDatabaseProviderConnection.Capability.CreateSpatialIndex
+                | QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists
+            ):
                 options = QgsAbstractDatabaseProviderConnection.SpatialIndexOptions()
                 options.geometryColumnName = self.geometryColumnName
 
-                if not conn.spatialIndexExists(schema, self.myNewTable, options.geometryColumnName):
+                if not conn.spatialIndexExists(
+                    schema, self.myNewTable, options.geometryColumnName
+                ):
                     conn.createSpatialIndex(schema, self.myNewTable, options)
 
-                self.assertTrue(conn.spatialIndexExists(schema, self.myNewTable, self.geometryColumnName))
+                self.assertTrue(
+                    conn.spatialIndexExists(
+                        schema, self.myNewTable, self.geometryColumnName
+                    )
+                )
 
                 # now we know for certain a spatial index exists, let's retry dropping it
-                if capabilities & QgsAbstractDatabaseProviderConnection.Capability.DeleteSpatialIndex:
-                    conn.deleteSpatialIndex(schema, self.myNewTable, self.geometryColumnName)
-                    if capabilities & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists:
-                        self.assertFalse(conn.spatialIndexExists(schema, self.myNewTable, self.geometryColumnName))
+                if (
+                    capabilities
+                    & QgsAbstractDatabaseProviderConnection.Capability.DeleteSpatialIndex
+                ):
+                    conn.deleteSpatialIndex(
+                        schema, self.myNewTable, self.geometryColumnName
+                    )
+                    if (
+                        capabilities
+                        & QgsAbstractDatabaseProviderConnection.Capability.SpatialIndexExists
+                    ):
+                        self.assertFalse(
+                            conn.spatialIndexExists(
+                                schema, self.myNewTable, self.geometryColumnName
+                            )
+                        )
 
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.DropSchema:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.DropSchema
+            ):
                 # Drop schema (should fail)
                 with self.assertRaises(QgsProviderConnectionException) as ex:
                     conn.dropSchema(schema)
@@ -396,13 +548,17 @@ class TestPyQgsProviderConnectionBase():
             self.assertEqual(ct.crs, QgsCoordinateReferenceSystem.fromEpsgId(3857))
             self.assertEqual(ct.wkbType, line_wkb_type)
             # Add a new (existing type)
-            table.addGeometryColumnType(line_wkb_type, QgsCoordinateReferenceSystem.fromEpsgId(3857))
+            table.addGeometryColumnType(
+                line_wkb_type, QgsCoordinateReferenceSystem.fromEpsgId(3857)
+            )
             self.assertEqual(len(table.geometryColumnTypes()), 1)
             ct = table.geometryColumnTypes()[0]
             self.assertEqual(ct.crs, QgsCoordinateReferenceSystem.fromEpsgId(3857))
             self.assertEqual(ct.wkbType, line_wkb_type)
             # Add a new one
-            table.addGeometryColumnType(line_wkb_type, QgsCoordinateReferenceSystem.fromEpsgId(4326))
+            table.addGeometryColumnType(
+                line_wkb_type, QgsCoordinateReferenceSystem.fromEpsgId(4326)
+            )
             self.assertEqual(len(table.geometryColumnTypes()), 2)
             ct = table.geometryColumnTypes()[0]
             self.assertEqual(ct.crs, QgsCoordinateReferenceSystem.fromEpsgId(3857))
@@ -413,39 +569,57 @@ class TestPyQgsProviderConnectionBase():
 
             # Check fields
             fields = conn.fields(schema, self.myNewTable)
-            for f in ['string_t', 'long_t', 'double_t', 'integer_t', 'date_t', 'datetime_t', 'time_t']:
+            for f in [
+                "string_t",
+                "long_t",
+                "double_t",
+                "integer_t",
+                "date_t",
+                "datetime_t",
+                "time_t",
+            ]:
                 self.assertIn(f, fields.names())
 
             if capabilities & QgsAbstractDatabaseProviderConnection.Capability.AddField:
-                field = QgsField('short_lived_field', QVariant.Int, 'integer')
+                field = QgsField("short_lived_field", QVariant.Int, "integer")
                 conn.addField(field, schema, self.myNewTable)
                 fields = conn.fields(schema, self.myNewTable)
-                self.assertIn('short_lived_field', fields.names())
+                self.assertIn("short_lived_field", fields.names())
 
-                if capabilities & QgsAbstractDatabaseProviderConnection.Capability.DeleteField:
-                    conn.deleteField('short_lived_field', schema, self.myNewTable)
+                if (
+                    capabilities
+                    & QgsAbstractDatabaseProviderConnection.Capability.DeleteField
+                ):
+                    conn.deleteField("short_lived_field", schema, self.myNewTable)
                     # This fails on Travis for spatialite, for no particular reason
-                    if self.providerKey == 'spatialite' and not os.environ.get('TRAVIS', False):
+                    if self.providerKey == "spatialite" and not os.environ.get(
+                        "TRAVIS", False
+                    ):
                         fields = conn.fields(schema, self.myNewTable)
-                        self.assertNotIn('short_lived_field', fields.names())
+                        self.assertNotIn("short_lived_field", fields.names())
 
             # Drop table
             conn.dropVectorTable(schema, self.myNewTable)
-            conn.dropVectorTable(schema, 'myNewAspatialTable')
+            conn.dropVectorTable(schema, "myNewAspatialTable")
             table_names = self._table_names(conn.tables(schema))
             self.assertNotIn(self.myNewTable, table_names)
 
-            if capabilities & QgsAbstractDatabaseProviderConnection.Capability.DropSchema:
+            if (
+                capabilities
+                & QgsAbstractDatabaseProviderConnection.Capability.DropSchema
+            ):
                 # Drop schema
                 conn.dropSchema(schema)
                 self.assertNotIn(schema, conn.schemas())
 
         conns = md.connections()
-        self.assertTrue(isinstance(list(conns.values())[0], QgsAbstractDatabaseProviderConnection))
+        self.assertTrue(
+            isinstance(list(conns.values())[0], QgsAbstractDatabaseProviderConnection)
+        )
 
         # Remove connection
         spy_deleted = QSignalSpy(md.connectionDeleted)
-        md.deleteConnection('qgis_test1')
+        md.deleteConnection("qgis_test1")
         self.assertEqual(list(md.connections().values()), [])
         self.assertEqual(len(spy_deleted), 1)
 
@@ -455,17 +629,30 @@ class TestPyQgsProviderConnectionBase():
         md = QgsProviderRegistry.instance().providerMetadata(self.providerKey)
         conn = self._test_save_load(md, self.uri, self.configuration)
 
-        if conn.capabilities() & QgsAbstractDatabaseProviderConnection.Capability.Schemas:
+        if (
+            conn.capabilities()
+            & QgsAbstractDatabaseProviderConnection.Capability.Schemas
+        ):
             with self.assertRaises(QgsProviderConnectionException) as ex:
-                conn.createVectorTable('notExists', 'notReally', QgsFields(), QgsWkbTypes.Type.Point,
-                                       QgsCoordinateReferenceSystem(), False, {})
+                conn.createVectorTable(
+                    "notExists",
+                    "notReally",
+                    QgsFields(),
+                    QgsWkbTypes.Type.Point,
+                    QgsCoordinateReferenceSystem(),
+                    False,
+                    {},
+                )
 
-        if conn.capabilities() & QgsAbstractDatabaseProviderConnection.Capability.DropVectorTable:
+        if (
+            conn.capabilities()
+            & QgsAbstractDatabaseProviderConnection.Capability.DropVectorTable
+        ):
             with self.assertRaises(QgsProviderConnectionException) as ex:
                 conn.executeSql('DROP TABLE "notExists"')
 
         # Remove connection
-        md.deleteConnection('qgis_test1')
+        md.deleteConnection("qgis_test1")
         self.assertEqual(list(md.connections().values()), [])
 
     def test_connections(self):
@@ -483,7 +670,7 @@ class TestPyQgsProviderConnectionBase():
         self.assertEqual(len(changed_spy), 0)
 
         # if we try to save again, the connectionChanged signal should be emitted instead of connectionCreated
-        md.saveConnection(conn, 'qgis_test1')
+        md.saveConnection(conn, "qgis_test1")
         self.assertEqual(len(created_spy), 1)
         self.assertEqual(len(changed_spy), 1)
 
@@ -496,13 +683,21 @@ class TestPyQgsProviderConnectionBase():
         conn = md.createConnection(self.uri, {})
         native_types = conn.nativeTypes()
         names = [nt.mTypeName.lower() for nt in native_types]
-        self.assertTrue('integer' in names or 'decimal' in names or 'number' in names, names)
-        self.assertTrue('string' in names or 'text' in names or 'nvarchar' in names or 'varchar2' in names, names)
+        self.assertTrue(
+            "integer" in names or "decimal" in names or "number" in names, names
+        )
+        self.assertTrue(
+            "string" in names
+            or "text" in names
+            or "nvarchar" in names
+            or "varchar2" in names,
+            names,
+        )
 
     def testExecuteSqlCancel(self):
         """Test that feedback can cancel an executeSql query"""
 
-        if hasattr(self, 'slowQuery'):
+        if hasattr(self, "slowQuery"):
 
             md = QgsProviderRegistry.instance().providerMetadata(self.providerKey)
             conn = md.createConnection(self.uri, {})
@@ -516,9 +711,12 @@ class TestPyQgsProviderConnectionBase():
 
             start = time.time()
             QtCore.QTimer.singleShot(500, _cancel)
-            task = QgsTask.fromFunction('test long running query', _run)
+            task = QgsTask.fromFunction("test long running query", _run)
             QgsApplication.taskManager().addTask(task)
-            while task.status() not in [QgsTask.TaskStatus.Complete, QgsTask.TaskStatus.Terminated]:
+            while task.status() not in [
+                QgsTask.TaskStatus.Complete,
+                QgsTask.TaskStatus.Terminated,
+            ]:
                 QgsApplication.processEvents()
             end = time.time()
             self.assertLess(end - start, 1)
@@ -529,23 +727,34 @@ class TestPyQgsProviderConnectionBase():
         md = QgsProviderRegistry.instance().providerMetadata(self.providerKey)
         conn = md.createConnection(self.uri, {})
 
-        if not conn.capabilities() & QgsAbstractDatabaseProviderConnection.Capability.SqlLayers:
-            print(f"FIXME: {self.providerKey} data provider does not support query layers!")
+        if (
+            not conn.capabilities()
+            & QgsAbstractDatabaseProviderConnection.Capability.SqlLayers
+        ):
+            print(
+                f"FIXME: {self.providerKey} data provider does not support query layers!"
+            )
             return
 
-        schema = getattr(self, 'sqlVectorLayerSchema', None)
+        schema = getattr(self, "sqlVectorLayerSchema", None)
         if schema is None:
-            print(f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerSchema for query layers test!")
+            print(
+                f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerSchema for query layers test!"
+            )
             return
 
-        table = getattr(self, 'sqlVectorLayerTable', None)
+        table = getattr(self, "sqlVectorLayerTable", None)
         if table is None:
-            print(f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerTable for query layers test!")
+            print(
+                f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerTable for query layers test!"
+            )
             return
 
-        crs = getattr(self, 'sqlVectorLayerCrs', None)
+        crs = getattr(self, "sqlVectorLayerCrs", None)
         if crs is None:
-            print(f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerCrs for query layers test!")
+            print(
+                f"FIXME: {self.providerKey} data provider test case does not define self.sqlVectorLayerCrs for query layers test!"
+            )
             return
 
         sql_layer_capabilities = conn.sqlLayerDefinitionCapabilities()
@@ -554,11 +763,13 @@ class TestPyQgsProviderConnectionBase():
         table_info = conn.table(schema, table)
 
         options = QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions()
-        options.layerName = 'My SQL Layer'
+        options.layerName = "My SQL Layer"
 
         # Some providers do not support schema
-        if schema != '':
-            options.sql = f'SELECT * FROM "{table_info.schema()}"."{table_info.tableName()}"'
+        if schema != "":
+            options.sql = (
+                f'SELECT * FROM "{table_info.schema()}"."{table_info.tableName()}"'
+            )
         else:
             options.sql = f'SELECT * FROM "{table_info.tableName()}"'
 
@@ -588,16 +799,19 @@ class TestPyQgsProviderConnectionBase():
         # Some providers can also create SQL layer without an explicit geometry column
         if sql_layer_capabilities & Qgis.SqlLayerDefinitionCapability.GeometryColumn:
             options.primaryKeyColumns = table_info.primaryKeyColumns()
-            options.geometryColumn = ''
+            options.geometryColumn = ""
             vl = conn.createSqlVectorLayer(options)
             self.assertTrue(vl.isValid())
             self.assertTrue(vl.isSqlQuery())
             # This may fail for OGR where the provider is smart enough to guess the geometry column
-            if self.providerKey != 'ogr':
+            if self.providerKey != "ogr":
                 self.assertFalse(vl.isSpatial())
 
         # Some providers can also create SQL layer with filters
-        if sql_layer_capabilities & Qgis.SqlLayerDefinitionCapability.SubsetStringFilter:
+        if (
+            sql_layer_capabilities
+            & Qgis.SqlLayerDefinitionCapability.SubsetStringFilter
+        ):
             options.primaryKeyColumns = table_info.primaryKeyColumns()
             options.geometryColumn = table_info.geometryColumn()
             options.filter = f'"{options.primaryKeyColumns[0]}" > 0'
